#[test]
fn test() {
    use crate::{raw_tz_by_name, time_zone, tz_by_name};

    const TIME_ZONES: &[(tz::TimeZoneRef<'static>, &[u8], &[&str])] = &[
        (time_zone::africa::ACCRA, time_zone::africa::RAW_ACCRA, &[
            "Africa/Accra",
            "africa/accra",
            "AFRICA/ACCRA",
            "aFRICA/aCCRA",
            "AfRiCa/aCcRa",
            "aFrIcA/AcCrA",
        ]),
        (
            time_zone::africa::ADDIS_ABABA,
            time_zone::africa::RAW_ADDIS_ABABA,
            &[
                "Africa/Addis_Ababa",
                "africa/addis_ababa",
                "AFRICA/ADDIS_ABABA",
                "aFRICA/aDDIS_aBABA",
                "AfRiCa/aDdIs_aBaBa",
                "aFrIcA/AdDiS_AbAbA",
            ],
        ),
        (
            time_zone::africa::ALGIERS,
            time_zone::africa::RAW_ALGIERS,
            &[
                "Africa/Algiers",
                "africa/algiers",
                "AFRICA/ALGIERS",
                "aFRICA/aLGIERS",
                "AfRiCa/aLgIeRs",
                "aFrIcA/AlGiErS",
            ],
        ),
        (time_zone::africa::ASMARA, time_zone::africa::RAW_ASMARA, &[
            "Africa/Asmara",
            "africa/asmara",
            "AFRICA/ASMARA",
            "aFRICA/aSMARA",
            "AfRiCa/aSmArA",
            "aFrIcA/AsMaRa",
        ]),
        (time_zone::africa::ASMERA, time_zone::africa::RAW_ASMERA, &[
            "Africa/Asmera",
            "africa/asmera",
            "AFRICA/ASMERA",
            "aFRICA/aSMERA",
            "AfRiCa/aSmErA",
            "aFrIcA/AsMeRa",
        ]),
        (
            time_zone::africa::NAIROBI,
            time_zone::africa::RAW_NAIROBI,
            &[
                "Africa/Nairobi",
                "africa/nairobi",
                "AFRICA/NAIROBI",
                "aFRICA/nAIROBI",
                "AfRiCa/nAiRoBi",
                "aFrIcA/NaIrObI",
            ],
        ),
        (time_zone::africa::BAMAKO, time_zone::africa::RAW_BAMAKO, &[
            "Africa/Bamako",
            "africa/bamako",
            "AFRICA/BAMAKO",
            "aFRICA/bAMAKO",
            "AfRiCa/bAmAkO",
            "aFrIcA/BaMaKo",
        ]),
        (time_zone::africa::BANGUI, time_zone::africa::RAW_BANGUI, &[
            "Africa/Bangui",
            "africa/bangui",
            "AFRICA/BANGUI",
            "aFRICA/bANGUI",
            "AfRiCa/bAnGuI",
            "aFrIcA/BaNgUi",
        ]),
        (time_zone::africa::BANJUL, time_zone::africa::RAW_BANJUL, &[
            "Africa/Banjul",
            "africa/banjul",
            "AFRICA/BANJUL",
            "aFRICA/bANJUL",
            "AfRiCa/bAnJuL",
            "aFrIcA/BaNjUl",
        ]),
        (time_zone::africa::BISSAU, time_zone::africa::RAW_BISSAU, &[
            "Africa/Bissau",
            "africa/bissau",
            "AFRICA/BISSAU",
            "aFRICA/bISSAU",
            "AfRiCa/bIsSaU",
            "aFrIcA/BiSsAu",
        ]),
        (
            time_zone::africa::BLANTYRE,
            time_zone::africa::RAW_BLANTYRE,
            &[
                "Africa/Blantyre",
                "africa/blantyre",
                "AFRICA/BLANTYRE",
                "aFRICA/bLANTYRE",
                "AfRiCa/bLaNtYrE",
                "aFrIcA/BlAnTyRe",
            ],
        ),
        (
            time_zone::africa::BRAZZAVILLE,
            time_zone::africa::RAW_BRAZZAVILLE,
            &[
                "Africa/Brazzaville",
                "africa/brazzaville",
                "AFRICA/BRAZZAVILLE",
                "aFRICA/bRAZZAVILLE",
                "AfRiCa/bRaZzAvIlLe",
                "aFrIcA/BrAzZaViLlE",
            ],
        ),
        (
            time_zone::africa::BUJUMBURA,
            time_zone::africa::RAW_BUJUMBURA,
            &[
                "Africa/Bujumbura",
                "africa/bujumbura",
                "AFRICA/BUJUMBURA",
                "aFRICA/bUJUMBURA",
                "AfRiCa/bUjUmBuRa",
                "aFrIcA/BuJuMbUrA",
            ],
        ),
        (
            time_zone::africa::CASABLANCA,
            time_zone::africa::RAW_CASABLANCA,
            &[
                "Africa/Casablanca",
                "africa/casablanca",
                "AFRICA/CASABLANCA",
                "aFRICA/cASABLANCA",
                "AfRiCa/cAsAbLaNcA",
                "aFrIcA/CaSaBlAnCa",
            ],
        ),
        (time_zone::africa::CEUTA, time_zone::africa::RAW_CEUTA, &[
            "Africa/Ceuta",
            "africa/ceuta",
            "AFRICA/CEUTA",
            "aFRICA/cEUTA",
            "AfRiCa/cEuTa",
            "aFrIcA/CeUtA",
        ]),
        (
            time_zone::africa::CONAKRY,
            time_zone::africa::RAW_CONAKRY,
            &[
                "Africa/Conakry",
                "africa/conakry",
                "AFRICA/CONAKRY",
                "aFRICA/cONAKRY",
                "AfRiCa/cOnAkRy",
                "aFrIcA/CoNaKrY",
            ],
        ),
        (time_zone::africa::DAKAR, time_zone::africa::RAW_DAKAR, &[
            "Africa/Dakar",
            "africa/dakar",
            "AFRICA/DAKAR",
            "aFRICA/dAKAR",
            "AfRiCa/dAkAr",
            "aFrIcA/DaKaR",
        ]),
        (
            time_zone::africa::DAR_ES_SALAAM,
            time_zone::africa::RAW_DAR_ES_SALAAM,
            &[
                "Africa/Dar_es_Salaam",
                "africa/dar_es_salaam",
                "AFRICA/DAR_ES_SALAAM",
                "aFRICA/dAR_ES_sALAAM",
                "AfRiCa/dAr_eS_SaLaAm",
                "aFrIcA/DaR_Es_sAlAaM",
            ],
        ),
        (
            time_zone::africa::DJIBOUTI,
            time_zone::africa::RAW_DJIBOUTI,
            &[
                "Africa/Djibouti",
                "africa/djibouti",
                "AFRICA/DJIBOUTI",
                "aFRICA/dJIBOUTI",
                "AfRiCa/dJiBoUtI",
                "aFrIcA/DjIbOuTi",
            ],
        ),
        (time_zone::africa::DOUALA, time_zone::africa::RAW_DOUALA, &[
            "Africa/Douala",
            "africa/douala",
            "AFRICA/DOUALA",
            "aFRICA/dOUALA",
            "AfRiCa/dOuAlA",
            "aFrIcA/DoUaLa",
        ]),
        (
            time_zone::africa::EL_AAIUN,
            time_zone::africa::RAW_EL_AAIUN,
            &[
                "Africa/El_Aaiun",
                "africa/el_aaiun",
                "AFRICA/EL_AAIUN",
                "aFRICA/eL_aAIUN",
                "AfRiCa/eL_AaIuN",
                "aFrIcA/El_aAiUn",
            ],
        ),
        (
            time_zone::africa::FREETOWN,
            time_zone::africa::RAW_FREETOWN,
            &[
                "Africa/Freetown",
                "africa/freetown",
                "AFRICA/FREETOWN",
                "aFRICA/fREETOWN",
                "AfRiCa/fReEtOwN",
                "aFrIcA/FrEeToWn",
            ],
        ),
        (
            time_zone::africa::GABORONE,
            time_zone::africa::RAW_GABORONE,
            &[
                "Africa/Gaborone",
                "africa/gaborone",
                "AFRICA/GABORONE",
                "aFRICA/gABORONE",
                "AfRiCa/gAbOrOnE",
                "aFrIcA/GaBoRoNe",
            ],
        ),
        (time_zone::africa::HARARE, time_zone::africa::RAW_HARARE, &[
            "Africa/Harare",
            "africa/harare",
            "AFRICA/HARARE",
            "aFRICA/hARARE",
            "AfRiCa/hArArE",
            "aFrIcA/HaRaRe",
        ]),
        (
            time_zone::africa::JOHANNESBURG,
            time_zone::africa::RAW_JOHANNESBURG,
            &[
                "Africa/Johannesburg",
                "africa/johannesburg",
                "AFRICA/JOHANNESBURG",
                "aFRICA/jOHANNESBURG",
                "AfRiCa/jOhAnNeSbUrG",
                "aFrIcA/JoHaNnEsBuRg",
            ],
        ),
        (time_zone::africa::JUBA, time_zone::africa::RAW_JUBA, &[
            "Africa/Juba",
            "africa/juba",
            "AFRICA/JUBA",
            "aFRICA/jUBA",
            "AfRiCa/jUbA",
            "aFrIcA/JuBa",
        ]),
        (
            time_zone::africa::KAMPALA,
            time_zone::africa::RAW_KAMPALA,
            &[
                "Africa/Kampala",
                "africa/kampala",
                "AFRICA/KAMPALA",
                "aFRICA/kAMPALA",
                "AfRiCa/kAmPaLa",
                "aFrIcA/KaMpAlA",
            ],
        ),
        (
            time_zone::africa::KHARTOUM,
            time_zone::africa::RAW_KHARTOUM,
            &[
                "Africa/Khartoum",
                "africa/khartoum",
                "AFRICA/KHARTOUM",
                "aFRICA/kHARTOUM",
                "AfRiCa/kHaRtOuM",
                "aFrIcA/KhArToUm",
            ],
        ),
        (time_zone::africa::KIGALI, time_zone::africa::RAW_KIGALI, &[
            "Africa/Kigali",
            "africa/kigali",
            "AFRICA/KIGALI",
            "aFRICA/kIGALI",
            "AfRiCa/kIgAlI",
            "aFrIcA/KiGaLi",
        ]),
        (
            time_zone::africa::KINSHASA,
            time_zone::africa::RAW_KINSHASA,
            &[
                "Africa/Kinshasa",
                "africa/kinshasa",
                "AFRICA/KINSHASA",
                "aFRICA/kINSHASA",
                "AfRiCa/kInShAsA",
                "aFrIcA/KiNsHaSa",
            ],
        ),
        (time_zone::africa::LAGOS, time_zone::africa::RAW_LAGOS, &[
            "Africa/Lagos",
            "africa/lagos",
            "AFRICA/LAGOS",
            "aFRICA/lAGOS",
            "AfRiCa/lAgOs",
            "aFrIcA/LaGoS",
        ]),
        (
            time_zone::africa::LIBREVILLE,
            time_zone::africa::RAW_LIBREVILLE,
            &[
                "Africa/Libreville",
                "africa/libreville",
                "AFRICA/LIBREVILLE",
                "aFRICA/lIBREVILLE",
                "AfRiCa/lIbReViLlE",
                "aFrIcA/LiBrEvIlLe",
            ],
        ),
        (time_zone::africa::LOME, time_zone::africa::RAW_LOME, &[
            "Africa/Lome",
            "africa/lome",
            "AFRICA/LOME",
            "aFRICA/lOME",
            "AfRiCa/lOmE",
            "aFrIcA/LoMe",
        ]),
        (time_zone::africa::LUANDA, time_zone::africa::RAW_LUANDA, &[
            "Africa/Luanda",
            "africa/luanda",
            "AFRICA/LUANDA",
            "aFRICA/lUANDA",
            "AfRiCa/lUaNdA",
            "aFrIcA/LuAnDa",
        ]),
        (
            time_zone::africa::LUBUMBASHI,
            time_zone::africa::RAW_LUBUMBASHI,
            &[
                "Africa/Lubumbashi",
                "africa/lubumbashi",
                "AFRICA/LUBUMBASHI",
                "aFRICA/lUBUMBASHI",
                "AfRiCa/lUbUmBaShI",
                "aFrIcA/LuBuMbAsHi",
            ],
        ),
        (time_zone::africa::LUSAKA, time_zone::africa::RAW_LUSAKA, &[
            "Africa/Lusaka",
            "africa/lusaka",
            "AFRICA/LUSAKA",
            "aFRICA/lUSAKA",
            "AfRiCa/lUsAkA",
            "aFrIcA/LuSaKa",
        ]),
        (time_zone::africa::MALABO, time_zone::africa::RAW_MALABO, &[
            "Africa/Malabo",
            "africa/malabo",
            "AFRICA/MALABO",
            "aFRICA/mALABO",
            "AfRiCa/mAlAbO",
            "aFrIcA/MaLaBo",
        ]),
        (time_zone::africa::MAPUTO, time_zone::africa::RAW_MAPUTO, &[
            "Africa/Maputo",
            "africa/maputo",
            "AFRICA/MAPUTO",
            "aFRICA/mAPUTO",
            "AfRiCa/mApUtO",
            "aFrIcA/MaPuTo",
        ]),
        (time_zone::africa::MASERU, time_zone::africa::RAW_MASERU, &[
            "Africa/Maseru",
            "africa/maseru",
            "AFRICA/MASERU",
            "aFRICA/mASERU",
            "AfRiCa/mAsErU",
            "aFrIcA/MaSeRu",
        ]),
        (
            time_zone::africa::MBABANE,
            time_zone::africa::RAW_MBABANE,
            &[
                "Africa/Mbabane",
                "africa/mbabane",
                "AFRICA/MBABANE",
                "aFRICA/mBABANE",
                "AfRiCa/mBaBaNe",
                "aFrIcA/MbAbAnE",
            ],
        ),
        (
            time_zone::africa::MOGADISHU,
            time_zone::africa::RAW_MOGADISHU,
            &[
                "Africa/Mogadishu",
                "africa/mogadishu",
                "AFRICA/MOGADISHU",
                "aFRICA/mOGADISHU",
                "AfRiCa/mOgAdIsHu",
                "aFrIcA/MoGaDiShU",
            ],
        ),
        (
            time_zone::africa::MONROVIA,
            time_zone::africa::RAW_MONROVIA,
            &[
                "Africa/Monrovia",
                "africa/monrovia",
                "AFRICA/MONROVIA",
                "aFRICA/mONROVIA",
                "AfRiCa/mOnRoViA",
                "aFrIcA/MoNrOvIa",
            ],
        ),
        (
            time_zone::africa::NDJAMENA,
            time_zone::africa::RAW_NDJAMENA,
            &[
                "Africa/Ndjamena",
                "africa/ndjamena",
                "AFRICA/NDJAMENA",
                "aFRICA/nDJAMENA",
                "AfRiCa/nDjAmEnA",
                "aFrIcA/NdJaMeNa",
            ],
        ),
        (time_zone::africa::NIAMEY, time_zone::africa::RAW_NIAMEY, &[
            "Africa/Niamey",
            "africa/niamey",
            "AFRICA/NIAMEY",
            "aFRICA/nIAMEY",
            "AfRiCa/nIaMeY",
            "aFrIcA/NiAmEy",
        ]),
        (
            time_zone::africa::NOUAKCHOTT,
            time_zone::africa::RAW_NOUAKCHOTT,
            &[
                "Africa/Nouakchott",
                "africa/nouakchott",
                "AFRICA/NOUAKCHOTT",
                "aFRICA/nOUAKCHOTT",
                "AfRiCa/nOuAkChOtT",
                "aFrIcA/NoUaKcHoTt",
            ],
        ),
        (
            time_zone::africa::OUAGADOUGOU,
            time_zone::africa::RAW_OUAGADOUGOU,
            &[
                "Africa/Ouagadougou",
                "africa/ouagadougou",
                "AFRICA/OUAGADOUGOU",
                "aFRICA/oUAGADOUGOU",
                "AfRiCa/oUaGaDoUgOu",
                "aFrIcA/OuAgAdOuGoU",
            ],
        ),
        (
            time_zone::africa::PORTO_NOVO,
            time_zone::africa::RAW_PORTO_NOVO,
            &[
                "Africa/Porto-Novo",
                "africa/porto-novo",
                "AFRICA/PORTO-NOVO",
                "aFRICA/pORTO-nOVO",
                "AfRiCa/pOrTo-nOvO",
                "aFrIcA/PoRtO-NoVo",
            ],
        ),
        (
            time_zone::africa::SAO_TOME,
            time_zone::africa::RAW_SAO_TOME,
            &[
                "Africa/Sao_Tome",
                "africa/sao_tome",
                "AFRICA/SAO_TOME",
                "aFRICA/sAO_tOME",
                "AfRiCa/sAo_tOmE",
                "aFrIcA/SaO_ToMe",
            ],
        ),
        (time_zone::africa::TUNIS, time_zone::africa::RAW_TUNIS, &[
            "Africa/Tunis",
            "africa/tunis",
            "AFRICA/TUNIS",
            "aFRICA/tUNIS",
            "AfRiCa/tUnIs",
            "aFrIcA/TuNiS",
        ]),
        (
            time_zone::africa::WINDHOEK,
            time_zone::africa::RAW_WINDHOEK,
            &[
                "Africa/Windhoek",
                "africa/windhoek",
                "AFRICA/WINDHOEK",
                "aFRICA/wINDHOEK",
                "AfRiCa/wInDhOeK",
                "aFrIcA/WiNdHoEk",
            ],
        ),
        (time_zone::america::ADAK, time_zone::america::RAW_ADAK, &[
            "America/Adak",
            "america/adak",
            "AMERICA/ADAK",
            "aMERICA/aDAK",
            "AmErIcA/AdAk",
            "aMeRiCa/aDaK",
        ]),
        (time_zone::america::ATKA, time_zone::america::RAW_ATKA, &[
            "America/Atka",
            "america/atka",
            "AMERICA/ATKA",
            "aMERICA/aTKA",
            "AmErIcA/AtKa",
            "aMeRiCa/aTkA",
        ]),
        (time_zone::us::ALEUTIAN, time_zone::us::RAW_ALEUTIAN, &[
            "US/Aleutian",
            "us/aleutian",
            "US/ALEUTIAN",
            "us/aLEUTIAN",
            "Us/aLeUtIaN",
            "uS/AlEuTiAn",
        ]),
        (
            time_zone::america::ANCHORAGE,
            time_zone::america::RAW_ANCHORAGE,
            &[
                "America/Anchorage",
                "america/anchorage",
                "AMERICA/ANCHORAGE",
                "aMERICA/aNCHORAGE",
                "AmErIcA/AnChOrAgE",
                "aMeRiCa/aNcHoRaGe",
            ],
        ),
        (time_zone::us::ALASKA, time_zone::us::RAW_ALASKA, &[
            "US/Alaska",
            "us/alaska",
            "US/ALASKA",
            "us/aLASKA",
            "Us/aLaSkA",
            "uS/AlAsKa",
        ]),
        (
            time_zone::america::ANGUILLA,
            time_zone::america::RAW_ANGUILLA,
            &[
                "America/Anguilla",
                "america/anguilla",
                "AMERICA/ANGUILLA",
                "aMERICA/aNGUILLA",
                "AmErIcA/AnGuIlLa",
                "aMeRiCa/aNgUiLlA",
            ],
        ),
        (
            time_zone::america::ANTIGUA,
            time_zone::america::RAW_ANTIGUA,
            &[
                "America/Antigua",
                "america/antigua",
                "AMERICA/ANTIGUA",
                "aMERICA/aNTIGUA",
                "AmErIcA/AnTiGuA",
                "aMeRiCa/aNtIgUa",
            ],
        ),
        (
            time_zone::america::ARAGUAINA,
            time_zone::america::RAW_ARAGUAINA,
            &[
                "America/Araguaina",
                "america/araguaina",
                "AMERICA/ARAGUAINA",
                "aMERICA/aRAGUAINA",
                "AmErIcA/ArAgUaInA",
                "aMeRiCa/aRaGuAiNa",
            ],
        ),
        (time_zone::america::ARUBA, time_zone::america::RAW_ARUBA, &[
            "America/Aruba",
            "america/aruba",
            "AMERICA/ARUBA",
            "aMERICA/aRUBA",
            "AmErIcA/ArUbA",
            "aMeRiCa/aRuBa",
        ]),
        (
            time_zone::america::ASUNCION,
            time_zone::america::RAW_ASUNCION,
            &[
                "America/Asuncion",
                "america/asuncion",
                "AMERICA/ASUNCION",
                "aMERICA/aSUNCION",
                "AmErIcA/AsUnCiOn",
                "aMeRiCa/aSuNcIoN",
            ],
        ),
        (
            time_zone::america::ATIKOKAN,
            time_zone::america::RAW_ATIKOKAN,
            &[
                "America/Atikokan",
                "america/atikokan",
                "AMERICA/ATIKOKAN",
                "aMERICA/aTIKOKAN",
                "AmErIcA/AtIkOkAn",
                "aMeRiCa/aTiKoKaN",
            ],
        ),
        (time_zone::america::BAHIA, time_zone::america::RAW_BAHIA, &[
            "America/Bahia",
            "america/bahia",
            "AMERICA/BAHIA",
            "aMERICA/bAHIA",
            "AmErIcA/BaHiA",
            "aMeRiCa/bAhIa",
        ]),
        (
            time_zone::america::BAHIA_BANDERAS,
            time_zone::america::RAW_BAHIA_BANDERAS,
            &[
                "America/Bahia_Banderas",
                "america/bahia_banderas",
                "AMERICA/BAHIA_BANDERAS",
                "aMERICA/bAHIA_bANDERAS",
                "AmErIcA/BaHiA_BaNdErAs",
                "aMeRiCa/bAhIa_bAnDeRaS",
            ],
        ),
        (
            time_zone::america::BARBADOS,
            time_zone::america::RAW_BARBADOS,
            &[
                "America/Barbados",
                "america/barbados",
                "AMERICA/BARBADOS",
                "aMERICA/bARBADOS",
                "AmErIcA/BaRbAdOs",
                "aMeRiCa/bArBaDoS",
            ],
        ),
        (time_zone::america::BELEM, time_zone::america::RAW_BELEM, &[
            "America/Belem",
            "america/belem",
            "AMERICA/BELEM",
            "aMERICA/bELEM",
            "AmErIcA/BeLeM",
            "aMeRiCa/bElEm",
        ]),
        (
            time_zone::america::BELIZE,
            time_zone::america::RAW_BELIZE,
            &[
                "America/Belize",
                "america/belize",
                "AMERICA/BELIZE",
                "aMERICA/bELIZE",
                "AmErIcA/BeLiZe",
                "aMeRiCa/bElIzE",
            ],
        ),
        (
            time_zone::america::BLANC_SABLON,
            time_zone::america::RAW_BLANC_SABLON,
            &[
                "America/Blanc-Sablon",
                "america/blanc-sablon",
                "AMERICA/BLANC-SABLON",
                "aMERICA/bLANC-sABLON",
                "AmErIcA/BlAnC-SaBlOn",
                "aMeRiCa/bLaNc-sAbLoN",
            ],
        ),
        (
            time_zone::america::BOA_VISTA,
            time_zone::america::RAW_BOA_VISTA,
            &[
                "America/Boa_Vista",
                "america/boa_vista",
                "AMERICA/BOA_VISTA",
                "aMERICA/bOA_vISTA",
                "AmErIcA/BoA_ViStA",
                "aMeRiCa/bOa_vIsTa",
            ],
        ),
        (
            time_zone::america::BOGOTA,
            time_zone::america::RAW_BOGOTA,
            &[
                "America/Bogota",
                "america/bogota",
                "AMERICA/BOGOTA",
                "aMERICA/bOGOTA",
                "AmErIcA/BoGoTa",
                "aMeRiCa/bOgOtA",
            ],
        ),
        (time_zone::america::BOISE, time_zone::america::RAW_BOISE, &[
            "America/Boise",
            "america/boise",
            "AMERICA/BOISE",
            "aMERICA/bOISE",
            "AmErIcA/BoIsE",
            "aMeRiCa/bOiSe",
        ]),
        (
            time_zone::america::BUENOS_AIRES,
            time_zone::america::RAW_BUENOS_AIRES,
            &[
                "America/Buenos_Aires",
                "america/buenos_aires",
                "AMERICA/BUENOS_AIRES",
                "aMERICA/bUENOS_aIRES",
                "AmErIcA/BuEnOs_aIrEs",
                "aMeRiCa/bUeNoS_AiReS",
            ],
        ),
        (
            time_zone::america::CAMBRIDGE_BAY,
            time_zone::america::RAW_CAMBRIDGE_BAY,
            &[
                "America/Cambridge_Bay",
                "america/cambridge_bay",
                "AMERICA/CAMBRIDGE_BAY",
                "aMERICA/cAMBRIDGE_bAY",
                "AmErIcA/CaMbRiDgE_BaY",
                "aMeRiCa/cAmBrIdGe_bAy",
            ],
        ),
        (
            time_zone::america::CAMPO_GRANDE,
            time_zone::america::RAW_CAMPO_GRANDE,
            &[
                "America/Campo_Grande",
                "america/campo_grande",
                "AMERICA/CAMPO_GRANDE",
                "aMERICA/cAMPO_gRANDE",
                "AmErIcA/CaMpO_GrAnDe",
                "aMeRiCa/cAmPo_gRaNdE",
            ],
        ),
        (
            time_zone::america::CANCUN,
            time_zone::america::RAW_CANCUN,
            &[
                "America/Cancun",
                "america/cancun",
                "AMERICA/CANCUN",
                "aMERICA/cANCUN",
                "AmErIcA/CaNcUn",
                "aMeRiCa/cAnCuN",
            ],
        ),
        (
            time_zone::america::CARACAS,
            time_zone::america::RAW_CARACAS,
            &[
                "America/Caracas",
                "america/caracas",
                "AMERICA/CARACAS",
                "aMERICA/cARACAS",
                "AmErIcA/CaRaCaS",
                "aMeRiCa/cArAcAs",
            ],
        ),
        (
            time_zone::america::CATAMARCA,
            time_zone::america::RAW_CATAMARCA,
            &[
                "America/Catamarca",
                "america/catamarca",
                "AMERICA/CATAMARCA",
                "aMERICA/cATAMARCA",
                "AmErIcA/CaTaMaRcA",
                "aMeRiCa/cAtAmArCa",
            ],
        ),
        (
            time_zone::america::CAYENNE,
            time_zone::america::RAW_CAYENNE,
            &[
                "America/Cayenne",
                "america/cayenne",
                "AMERICA/CAYENNE",
                "aMERICA/cAYENNE",
                "AmErIcA/CaYeNnE",
                "aMeRiCa/cAyEnNe",
            ],
        ),
        (
            time_zone::america::CAYMAN,
            time_zone::america::RAW_CAYMAN,
            &[
                "America/Cayman",
                "america/cayman",
                "AMERICA/CAYMAN",
                "aMERICA/cAYMAN",
                "AmErIcA/CaYmAn",
                "aMeRiCa/cAyMaN",
            ],
        ),
        (
            time_zone::america::CHICAGO,
            time_zone::america::RAW_CHICAGO,
            &[
                "America/Chicago",
                "america/chicago",
                "AMERICA/CHICAGO",
                "aMERICA/cHICAGO",
                "AmErIcA/ChIcAgO",
                "aMeRiCa/cHiCaGo",
            ],
        ),
        (time_zone::us::CENTRAL, time_zone::us::RAW_CENTRAL, &[
            "US/Central",
            "us/central",
            "US/CENTRAL",
            "us/cENTRAL",
            "Us/cEnTrAl",
            "uS/CeNtRaL",
        ]),
        (
            time_zone::america::CHIHUAHUA,
            time_zone::america::RAW_CHIHUAHUA,
            &[
                "America/Chihuahua",
                "america/chihuahua",
                "AMERICA/CHIHUAHUA",
                "aMERICA/cHIHUAHUA",
                "AmErIcA/ChIhUaHuA",
                "aMeRiCa/cHiHuAhUa",
            ],
        ),
        (
            time_zone::america::CIUDAD_JUAREZ,
            time_zone::america::RAW_CIUDAD_JUAREZ,
            &[
                "America/Ciudad_Juarez",
                "america/ciudad_juarez",
                "AMERICA/CIUDAD_JUAREZ",
                "aMERICA/cIUDAD_jUAREZ",
                "AmErIcA/CiUdAd_jUaReZ",
                "aMeRiCa/cIuDaD_JuArEz",
            ],
        ),
        (
            time_zone::america::CORAL_HARBOUR,
            time_zone::america::RAW_CORAL_HARBOUR,
            &[
                "America/Coral_Harbour",
                "america/coral_harbour",
                "AMERICA/CORAL_HARBOUR",
                "aMERICA/cORAL_hARBOUR",
                "AmErIcA/CoRaL_HaRbOuR",
                "aMeRiCa/cOrAl_hArBoUr",
            ],
        ),
        (
            time_zone::america::PANAMA,
            time_zone::america::RAW_PANAMA,
            &[
                "America/Panama",
                "america/panama",
                "AMERICA/PANAMA",
                "aMERICA/pANAMA",
                "AmErIcA/PaNaMa",
                "aMeRiCa/pAnAmA",
            ],
        ),
        (
            time_zone::america::CORDOBA,
            time_zone::america::RAW_CORDOBA,
            &[
                "America/Cordoba",
                "america/cordoba",
                "AMERICA/CORDOBA",
                "aMERICA/cORDOBA",
                "AmErIcA/CoRdObA",
                "aMeRiCa/cOrDoBa",
            ],
        ),
        (
            time_zone::america::ROSARIO,
            time_zone::america::RAW_ROSARIO,
            &[
                "America/Rosario",
                "america/rosario",
                "AMERICA/ROSARIO",
                "aMERICA/rOSARIO",
                "AmErIcA/RoSaRiO",
                "aMeRiCa/rOsArIo",
            ],
        ),
        (
            time_zone::america::COSTA_RICA,
            time_zone::america::RAW_COSTA_RICA,
            &[
                "America/Costa_Rica",
                "america/costa_rica",
                "AMERICA/COSTA_RICA",
                "aMERICA/cOSTA_rICA",
                "AmErIcA/CoStA_RiCa",
                "aMeRiCa/cOsTa_rIcA",
            ],
        ),
        (
            time_zone::america::CRESTON,
            time_zone::america::RAW_CRESTON,
            &[
                "America/Creston",
                "america/creston",
                "AMERICA/CRESTON",
                "aMERICA/cRESTON",
                "AmErIcA/CrEsToN",
                "aMeRiCa/cReStOn",
            ],
        ),
        (
            time_zone::america::CUIABA,
            time_zone::america::RAW_CUIABA,
            &[
                "America/Cuiaba",
                "america/cuiaba",
                "AMERICA/CUIABA",
                "aMERICA/cUIABA",
                "AmErIcA/CuIaBa",
                "aMeRiCa/cUiAbA",
            ],
        ),
        (
            time_zone::america::CURACAO,
            time_zone::america::RAW_CURACAO,
            &[
                "America/Curacao",
                "america/curacao",
                "AMERICA/CURACAO",
                "aMERICA/cURACAO",
                "AmErIcA/CuRaCaO",
                "aMeRiCa/cUrAcAo",
            ],
        ),
        (
            time_zone::america::DANMARKSHAVN,
            time_zone::america::RAW_DANMARKSHAVN,
            &[
                "America/Danmarkshavn",
                "america/danmarkshavn",
                "AMERICA/DANMARKSHAVN",
                "aMERICA/dANMARKSHAVN",
                "AmErIcA/DaNmArKsHaVn",
                "aMeRiCa/dAnMaRkShAvN",
            ],
        ),
        (
            time_zone::america::DAWSON,
            time_zone::america::RAW_DAWSON,
            &[
                "America/Dawson",
                "america/dawson",
                "AMERICA/DAWSON",
                "aMERICA/dAWSON",
                "AmErIcA/DaWsOn",
                "aMeRiCa/dAwSoN",
            ],
        ),
        (
            time_zone::america::DAWSON_CREEK,
            time_zone::america::RAW_DAWSON_CREEK,
            &[
                "America/Dawson_Creek",
                "america/dawson_creek",
                "AMERICA/DAWSON_CREEK",
                "aMERICA/dAWSON_cREEK",
                "AmErIcA/DaWsOn_cReEk",
                "aMeRiCa/dAwSoN_CrEeK",
            ],
        ),
        (
            time_zone::america::DETROIT,
            time_zone::america::RAW_DETROIT,
            &[
                "America/Detroit",
                "america/detroit",
                "AMERICA/DETROIT",
                "aMERICA/dETROIT",
                "AmErIcA/DeTrOiT",
                "aMeRiCa/dEtRoIt",
            ],
        ),
        (time_zone::us::MICHIGAN, time_zone::us::RAW_MICHIGAN, &[
            "US/Michigan",
            "us/michigan",
            "US/MICHIGAN",
            "us/mICHIGAN",
            "Us/mIcHiGaN",
            "uS/MiChIgAn",
        ]),
        (
            time_zone::america::DOMINICA,
            time_zone::america::RAW_DOMINICA,
            &[
                "America/Dominica",
                "america/dominica",
                "AMERICA/DOMINICA",
                "aMERICA/dOMINICA",
                "AmErIcA/DoMiNiCa",
                "aMeRiCa/dOmInIcA",
            ],
        ),
        (
            time_zone::america::EDMONTON,
            time_zone::america::RAW_EDMONTON,
            &[
                "America/Edmonton",
                "america/edmonton",
                "AMERICA/EDMONTON",
                "aMERICA/eDMONTON",
                "AmErIcA/EdMoNtOn",
                "aMeRiCa/eDmOnToN",
            ],
        ),
        (
            time_zone::america::YELLOWKNIFE,
            time_zone::america::RAW_YELLOWKNIFE,
            &[
                "America/Yellowknife",
                "america/yellowknife",
                "AMERICA/YELLOWKNIFE",
                "aMERICA/yELLOWKNIFE",
                "AmErIcA/YeLlOwKnIfE",
                "aMeRiCa/yElLoWkNiFe",
            ],
        ),
        (
            time_zone::canada::MOUNTAIN,
            time_zone::canada::RAW_MOUNTAIN,
            &[
                "Canada/Mountain",
                "canada/mountain",
                "CANADA/MOUNTAIN",
                "cANADA/mOUNTAIN",
                "CaNaDa/mOuNtAiN",
                "cAnAdA/MoUnTaIn",
            ],
        ),
        (
            time_zone::america::EIRUNEPE,
            time_zone::america::RAW_EIRUNEPE,
            &[
                "America/Eirunepe",
                "america/eirunepe",
                "AMERICA/EIRUNEPE",
                "aMERICA/eIRUNEPE",
                "AmErIcA/EiRuNePe",
                "aMeRiCa/eIrUnEpE",
            ],
        ),
        (
            time_zone::america::EL_SALVADOR,
            time_zone::america::RAW_EL_SALVADOR,
            &[
                "America/El_Salvador",
                "america/el_salvador",
                "AMERICA/EL_SALVADOR",
                "aMERICA/eL_sALVADOR",
                "AmErIcA/El_sAlVaDoR",
                "aMeRiCa/eL_SaLvAdOr",
            ],
        ),
        (
            time_zone::america::ENSENADA,
            time_zone::america::RAW_ENSENADA,
            &[
                "America/Ensenada",
                "america/ensenada",
                "AMERICA/ENSENADA",
                "aMERICA/eNSENADA",
                "AmErIcA/EnSeNaDa",
                "aMeRiCa/eNsEnAdA",
            ],
        ),
        (
            time_zone::america::SANTA_ISABEL,
            time_zone::america::RAW_SANTA_ISABEL,
            &[
                "America/Santa_Isabel",
                "america/santa_isabel",
                "AMERICA/SANTA_ISABEL",
                "aMERICA/sANTA_iSABEL",
                "AmErIcA/SaNtA_IsAbEl",
                "aMeRiCa/sAnTa_iSaBeL",
            ],
        ),
        (
            time_zone::america::TIJUANA,
            time_zone::america::RAW_TIJUANA,
            &[
                "America/Tijuana",
                "america/tijuana",
                "AMERICA/TIJUANA",
                "aMERICA/tIJUANA",
                "AmErIcA/TiJuAnA",
                "aMeRiCa/tIjUaNa",
            ],
        ),
        (
            time_zone::mexico::BAJA_NORTE,
            time_zone::mexico::RAW_BAJA_NORTE,
            &[
                "Mexico/BajaNorte",
                "mexico/bajanorte",
                "MEXICO/BAJANORTE",
                "mEXICO/bAJAnORTE",
                "MeXiCo/bAjAnOrTe",
                "mExIcO/BaJaNoRtE",
            ],
        ),
        (
            time_zone::america::FORTALEZA,
            time_zone::america::RAW_FORTALEZA,
            &[
                "America/Fortaleza",
                "america/fortaleza",
                "AMERICA/FORTALEZA",
                "aMERICA/fORTALEZA",
                "AmErIcA/FoRtAlEzA",
                "aMeRiCa/fOrTaLeZa",
            ],
        ),
        (
            time_zone::america::FORT_NELSON,
            time_zone::america::RAW_FORT_NELSON,
            &[
                "America/Fort_Nelson",
                "america/fort_nelson",
                "AMERICA/FORT_NELSON",
                "aMERICA/fORT_nELSON",
                "AmErIcA/FoRt_nElSoN",
                "aMeRiCa/fOrT_NeLsOn",
            ],
        ),
        (
            time_zone::america::FORT_WAYNE,
            time_zone::america::RAW_FORT_WAYNE,
            &[
                "America/Fort_Wayne",
                "america/fort_wayne",
                "AMERICA/FORT_WAYNE",
                "aMERICA/fORT_wAYNE",
                "AmErIcA/FoRt_wAyNe",
                "aMeRiCa/fOrT_WaYnE",
            ],
        ),
        (
            time_zone::america::INDIANAPOLIS,
            time_zone::america::RAW_INDIANAPOLIS,
            &[
                "America/Indianapolis",
                "america/indianapolis",
                "AMERICA/INDIANAPOLIS",
                "aMERICA/iNDIANAPOLIS",
                "AmErIcA/InDiAnApOlIs",
                "aMeRiCa/iNdIaNaPoLiS",
            ],
        ),
        (
            time_zone::us::EAST_INDIANA,
            time_zone::us::RAW_EAST_INDIANA,
            &[
                "US/East-Indiana",
                "us/east-indiana",
                "US/EAST-INDIANA",
                "us/eAST-iNDIANA",
                "Us/eAsT-InDiAnA",
                "uS/EaSt-iNdIaNa",
            ],
        ),
        (
            time_zone::america::GLACE_BAY,
            time_zone::america::RAW_GLACE_BAY,
            &[
                "America/Glace_Bay",
                "america/glace_bay",
                "AMERICA/GLACE_BAY",
                "aMERICA/gLACE_bAY",
                "AmErIcA/GlAcE_BaY",
                "aMeRiCa/gLaCe_bAy",
            ],
        ),
        (
            time_zone::america::GODTHAB,
            time_zone::america::RAW_GODTHAB,
            &[
                "America/Godthab",
                "america/godthab",
                "AMERICA/GODTHAB",
                "aMERICA/gODTHAB",
                "AmErIcA/GoDtHaB",
                "aMeRiCa/gOdThAb",
            ],
        ),
        (time_zone::america::NUUK, time_zone::america::RAW_NUUK, &[
            "America/Nuuk",
            "america/nuuk",
            "AMERICA/NUUK",
            "aMERICA/nUUK",
            "AmErIcA/NuUk",
            "aMeRiCa/nUuK",
        ]),
        (
            time_zone::america::GOOSE_BAY,
            time_zone::america::RAW_GOOSE_BAY,
            &[
                "America/Goose_Bay",
                "america/goose_bay",
                "AMERICA/GOOSE_BAY",
                "aMERICA/gOOSE_bAY",
                "AmErIcA/GoOsE_BaY",
                "aMeRiCa/gOoSe_bAy",
            ],
        ),
        (
            time_zone::america::GRAND_TURK,
            time_zone::america::RAW_GRAND_TURK,
            &[
                "America/Grand_Turk",
                "america/grand_turk",
                "AMERICA/GRAND_TURK",
                "aMERICA/gRAND_tURK",
                "AmErIcA/GrAnD_TuRk",
                "aMeRiCa/gRaNd_tUrK",
            ],
        ),
        (
            time_zone::america::GRENADA,
            time_zone::america::RAW_GRENADA,
            &[
                "America/Grenada",
                "america/grenada",
                "AMERICA/GRENADA",
                "aMERICA/gRENADA",
                "AmErIcA/GrEnAdA",
                "aMeRiCa/gReNaDa",
            ],
        ),
        (
            time_zone::america::GUADELOUPE,
            time_zone::america::RAW_GUADELOUPE,
            &[
                "America/Guadeloupe",
                "america/guadeloupe",
                "AMERICA/GUADELOUPE",
                "aMERICA/gUADELOUPE",
                "AmErIcA/GuAdElOuPe",
                "aMeRiCa/gUaDeLoUpE",
            ],
        ),
        (
            time_zone::america::GUATEMALA,
            time_zone::america::RAW_GUATEMALA,
            &[
                "America/Guatemala",
                "america/guatemala",
                "AMERICA/GUATEMALA",
                "aMERICA/gUATEMALA",
                "AmErIcA/GuAtEmAlA",
                "aMeRiCa/gUaTeMaLa",
            ],
        ),
        (
            time_zone::america::GUAYAQUIL,
            time_zone::america::RAW_GUAYAQUIL,
            &[
                "America/Guayaquil",
                "america/guayaquil",
                "AMERICA/GUAYAQUIL",
                "aMERICA/gUAYAQUIL",
                "AmErIcA/GuAyAqUiL",
                "aMeRiCa/gUaYaQuIl",
            ],
        ),
        (
            time_zone::america::GUYANA,
            time_zone::america::RAW_GUYANA,
            &[
                "America/Guyana",
                "america/guyana",
                "AMERICA/GUYANA",
                "aMERICA/gUYANA",
                "AmErIcA/GuYaNa",
                "aMeRiCa/gUyAnA",
            ],
        ),
        (
            time_zone::america::HALIFAX,
            time_zone::america::RAW_HALIFAX,
            &[
                "America/Halifax",
                "america/halifax",
                "AMERICA/HALIFAX",
                "aMERICA/hALIFAX",
                "AmErIcA/HaLiFaX",
                "aMeRiCa/hAlIfAx",
            ],
        ),
        (
            time_zone::canada::ATLANTIC,
            time_zone::canada::RAW_ATLANTIC,
            &[
                "Canada/Atlantic",
                "canada/atlantic",
                "CANADA/ATLANTIC",
                "cANADA/aTLANTIC",
                "CaNaDa/aTlAnTiC",
                "cAnAdA/AtLaNtIc",
            ],
        ),
        (
            time_zone::america::HERMOSILLO,
            time_zone::america::RAW_HERMOSILLO,
            &[
                "America/Hermosillo",
                "america/hermosillo",
                "AMERICA/HERMOSILLO",
                "aMERICA/hERMOSILLO",
                "AmErIcA/HeRmOsIlLo",
                "aMeRiCa/hErMoSiLlO",
            ],
        ),
        (
            time_zone::america::INUVIK,
            time_zone::america::RAW_INUVIK,
            &[
                "America/Inuvik",
                "america/inuvik",
                "AMERICA/INUVIK",
                "aMERICA/iNUVIK",
                "AmErIcA/InUvIk",
                "aMeRiCa/iNuViK",
            ],
        ),
        (
            time_zone::america::IQALUIT,
            time_zone::america::RAW_IQALUIT,
            &[
                "America/Iqaluit",
                "america/iqaluit",
                "AMERICA/IQALUIT",
                "aMERICA/iQALUIT",
                "AmErIcA/IqAlUiT",
                "aMeRiCa/iQaLuIt",
            ],
        ),
        (
            time_zone::america::PANGNIRTUNG,
            time_zone::america::RAW_PANGNIRTUNG,
            &[
                "America/Pangnirtung",
                "america/pangnirtung",
                "AMERICA/PANGNIRTUNG",
                "aMERICA/pANGNIRTUNG",
                "AmErIcA/PaNgNiRtUnG",
                "aMeRiCa/pAnGnIrTuNg",
            ],
        ),
        (time_zone::america::JUJUY, time_zone::america::RAW_JUJUY, &[
            "America/Jujuy",
            "america/jujuy",
            "AMERICA/JUJUY",
            "aMERICA/jUJUY",
            "AmErIcA/JuJuY",
            "aMeRiCa/jUjUy",
        ]),
        (
            time_zone::america::JUNEAU,
            time_zone::america::RAW_JUNEAU,
            &[
                "America/Juneau",
                "america/juneau",
                "AMERICA/JUNEAU",
                "aMERICA/jUNEAU",
                "AmErIcA/JuNeAu",
                "aMeRiCa/jUnEaU",
            ],
        ),
        (
            time_zone::america::KNOX_IN,
            time_zone::america::RAW_KNOX_IN,
            &[
                "America/Knox_IN",
                "america/knox_in",
                "AMERICA/KNOX_IN",
                "aMERICA/kNOX_in",
                "AmErIcA/KnOx_iN",
                "aMeRiCa/kNoX_In",
            ],
        ),
        (
            time_zone::us::INDIANA_STARKE,
            time_zone::us::RAW_INDIANA_STARKE,
            &[
                "US/Indiana-Starke",
                "us/indiana-starke",
                "US/INDIANA-STARKE",
                "us/iNDIANA-sTARKE",
                "Us/iNdIaNa-sTaRkE",
                "uS/InDiAnA-StArKe",
            ],
        ),
        (
            time_zone::america::KRALENDIJK,
            time_zone::america::RAW_KRALENDIJK,
            &[
                "America/Kralendijk",
                "america/kralendijk",
                "AMERICA/KRALENDIJK",
                "aMERICA/kRALENDIJK",
                "AmErIcA/KrAlEnDiJk",
                "aMeRiCa/kRaLeNdIjK",
            ],
        ),
        (
            time_zone::america::LOWER_PRINCES,
            time_zone::america::RAW_LOWER_PRINCES,
            &[
                "America/Lower_Princes",
                "america/lower_princes",
                "AMERICA/LOWER_PRINCES",
                "aMERICA/lOWER_pRINCES",
                "AmErIcA/LoWeR_PrInCeS",
                "aMeRiCa/lOwEr_pRiNcEs",
            ],
        ),
        (
            time_zone::america::MARIGOT,
            time_zone::america::RAW_MARIGOT,
            &[
                "America/Marigot",
                "america/marigot",
                "AMERICA/MARIGOT",
                "aMERICA/mARIGOT",
                "AmErIcA/MaRiGoT",
                "aMeRiCa/mArIgOt",
            ],
        ),
        (
            time_zone::america::PUERTO_RICO,
            time_zone::america::RAW_PUERTO_RICO,
            &[
                "America/Puerto_Rico",
                "america/puerto_rico",
                "AMERICA/PUERTO_RICO",
                "aMERICA/pUERTO_rICO",
                "AmErIcA/PuErTo_rIcO",
                "aMeRiCa/pUeRtO_RiCo",
            ],
        ),
        (
            time_zone::america::ST_BARTHELEMY,
            time_zone::america::RAW_ST_BARTHELEMY,
            &[
                "America/St_Barthelemy",
                "america/st_barthelemy",
                "AMERICA/ST_BARTHELEMY",
                "aMERICA/sT_bARTHELEMY",
                "AmErIcA/St_bArThElEmY",
                "aMeRiCa/sT_BaRtHeLeMy",
            ],
        ),
        (
            time_zone::america::VIRGIN,
            time_zone::america::RAW_VIRGIN,
            &[
                "America/Virgin",
                "america/virgin",
                "AMERICA/VIRGIN",
                "aMERICA/vIRGIN",
                "AmErIcA/ViRgIn",
                "aMeRiCa/vIrGiN",
            ],
        ),
        (
            time_zone::america::LA_PAZ,
            time_zone::america::RAW_LA_PAZ,
            &[
                "America/La_Paz",
                "america/la_paz",
                "AMERICA/LA_PAZ",
                "aMERICA/lA_pAZ",
                "AmErIcA/La_pAz",
                "aMeRiCa/lA_PaZ",
            ],
        ),
        (time_zone::america::LIMA, time_zone::america::RAW_LIMA, &[
            "America/Lima",
            "america/lima",
            "AMERICA/LIMA",
            "aMERICA/lIMA",
            "AmErIcA/LiMa",
            "aMeRiCa/lImA",
        ]),
        (
            time_zone::america::LOS_ANGELES,
            time_zone::america::RAW_LOS_ANGELES,
            &[
                "America/Los_Angeles",
                "america/los_angeles",
                "AMERICA/LOS_ANGELES",
                "aMERICA/lOS_aNGELES",
                "AmErIcA/LoS_AnGeLeS",
                "aMeRiCa/lOs_aNgElEs",
            ],
        ),
        (time_zone::us::PACIFIC, time_zone::us::RAW_PACIFIC, &[
            "US/Pacific",
            "us/pacific",
            "US/PACIFIC",
            "us/pACIFIC",
            "Us/pAcIfIc",
            "uS/PaCiFiC",
        ]),
        (
            time_zone::america::LOUISVILLE,
            time_zone::america::RAW_LOUISVILLE,
            &[
                "America/Louisville",
                "america/louisville",
                "AMERICA/LOUISVILLE",
                "aMERICA/lOUISVILLE",
                "AmErIcA/LoUiSvIlLe",
                "aMeRiCa/lOuIsViLlE",
            ],
        ),
        (
            time_zone::america::MACEIO,
            time_zone::america::RAW_MACEIO,
            &[
                "America/Maceio",
                "america/maceio",
                "AMERICA/MACEIO",
                "aMERICA/mACEIO",
                "AmErIcA/MaCeIo",
                "aMeRiCa/mAcEiO",
            ],
        ),
        (
            time_zone::america::MANAGUA,
            time_zone::america::RAW_MANAGUA,
            &[
                "America/Managua",
                "america/managua",
                "AMERICA/MANAGUA",
                "aMERICA/mANAGUA",
                "AmErIcA/MaNaGuA",
                "aMeRiCa/mAnAgUa",
            ],
        ),
        (
            time_zone::america::MANAUS,
            time_zone::america::RAW_MANAUS,
            &[
                "America/Manaus",
                "america/manaus",
                "AMERICA/MANAUS",
                "aMERICA/mANAUS",
                "AmErIcA/MaNaUs",
                "aMeRiCa/mAnAuS",
            ],
        ),
        (time_zone::brazil::WEST, time_zone::brazil::RAW_WEST, &[
            "Brazil/West",
            "brazil/west",
            "BRAZIL/WEST",
            "bRAZIL/wEST",
            "BrAzIl/wEsT",
            "bRaZiL/WeSt",
        ]),
        (
            time_zone::america::MARTINIQUE,
            time_zone::america::RAW_MARTINIQUE,
            &[
                "America/Martinique",
                "america/martinique",
                "AMERICA/MARTINIQUE",
                "aMERICA/mARTINIQUE",
                "AmErIcA/MaRtInIqUe",
                "aMeRiCa/mArTiNiQuE",
            ],
        ),
        (
            time_zone::america::MATAMOROS,
            time_zone::america::RAW_MATAMOROS,
            &[
                "America/Matamoros",
                "america/matamoros",
                "AMERICA/MATAMOROS",
                "aMERICA/mATAMOROS",
                "AmErIcA/MaTaMoRoS",
                "aMeRiCa/mAtAmOrOs",
            ],
        ),
        (
            time_zone::america::MAZATLAN,
            time_zone::america::RAW_MAZATLAN,
            &[
                "America/Mazatlan",
                "america/mazatlan",
                "AMERICA/MAZATLAN",
                "aMERICA/mAZATLAN",
                "AmErIcA/MaZaTlAn",
                "aMeRiCa/mAzAtLaN",
            ],
        ),
        (
            time_zone::mexico::BAJA_SUR,
            time_zone::mexico::RAW_BAJA_SUR,
            &[
                "Mexico/BajaSur",
                "mexico/bajasur",
                "MEXICO/BAJASUR",
                "mEXICO/bAJAsUR",
                "MeXiCo/bAjAsUr",
                "mExIcO/BaJaSuR",
            ],
        ),
        (
            time_zone::america::MENDOZA,
            time_zone::america::RAW_MENDOZA,
            &[
                "America/Mendoza",
                "america/mendoza",
                "AMERICA/MENDOZA",
                "aMERICA/mENDOZA",
                "AmErIcA/MeNdOzA",
                "aMeRiCa/mEnDoZa",
            ],
        ),
        (
            time_zone::america::MENOMINEE,
            time_zone::america::RAW_MENOMINEE,
            &[
                "America/Menominee",
                "america/menominee",
                "AMERICA/MENOMINEE",
                "aMERICA/mENOMINEE",
                "AmErIcA/MeNoMiNeE",
                "aMeRiCa/mEnOmInEe",
            ],
        ),
        (
            time_zone::america::MERIDA,
            time_zone::america::RAW_MERIDA,
            &[
                "America/Merida",
                "america/merida",
                "AMERICA/MERIDA",
                "aMERICA/mERIDA",
                "AmErIcA/MeRiDa",
                "aMeRiCa/mErIdA",
            ],
        ),
        (
            time_zone::america::METLAKATLA,
            time_zone::america::RAW_METLAKATLA,
            &[
                "America/Metlakatla",
                "america/metlakatla",
                "AMERICA/METLAKATLA",
                "aMERICA/mETLAKATLA",
                "AmErIcA/MeTlAkAtLa",
                "aMeRiCa/mEtLaKaTlA",
            ],
        ),
        (
            time_zone::america::MEXICO_CITY,
            time_zone::america::RAW_MEXICO_CITY,
            &[
                "America/Mexico_City",
                "america/mexico_city",
                "AMERICA/MEXICO_CITY",
                "aMERICA/mEXICO_cITY",
                "AmErIcA/MeXiCo_cItY",
                "aMeRiCa/mExIcO_CiTy",
            ],
        ),
        (
            time_zone::mexico::GENERAL,
            time_zone::mexico::RAW_GENERAL,
            &[
                "Mexico/General",
                "mexico/general",
                "MEXICO/GENERAL",
                "mEXICO/gENERAL",
                "MeXiCo/gEnErAl",
                "mExIcO/GeNeRaL",
            ],
        ),
        (
            time_zone::america::MIQUELON,
            time_zone::america::RAW_MIQUELON,
            &[
                "America/Miquelon",
                "america/miquelon",
                "AMERICA/MIQUELON",
                "aMERICA/mIQUELON",
                "AmErIcA/MiQuElOn",
                "aMeRiCa/mIqUeLoN",
            ],
        ),
        (
            time_zone::america::MONCTON,
            time_zone::america::RAW_MONCTON,
            &[
                "America/Moncton",
                "america/moncton",
                "AMERICA/MONCTON",
                "aMERICA/mONCTON",
                "AmErIcA/MoNcToN",
                "aMeRiCa/mOnCtOn",
            ],
        ),
        (
            time_zone::america::MONTERREY,
            time_zone::america::RAW_MONTERREY,
            &[
                "America/Monterrey",
                "america/monterrey",
                "AMERICA/MONTERREY",
                "aMERICA/mONTERREY",
                "AmErIcA/MoNtErReY",
                "aMeRiCa/mOnTeRrEy",
            ],
        ),
        (
            time_zone::america::MONTEVIDEO,
            time_zone::america::RAW_MONTEVIDEO,
            &[
                "America/Montevideo",
                "america/montevideo",
                "AMERICA/MONTEVIDEO",
                "aMERICA/mONTEVIDEO",
                "AmErIcA/MoNtEvIdEo",
                "aMeRiCa/mOnTeViDeO",
            ],
        ),
        (
            time_zone::america::MONTREAL,
            time_zone::america::RAW_MONTREAL,
            &[
                "America/Montreal",
                "america/montreal",
                "AMERICA/MONTREAL",
                "aMERICA/mONTREAL",
                "AmErIcA/MoNtReAl",
                "aMeRiCa/mOnTrEaL",
            ],
        ),
        (
            time_zone::america::NIPIGON,
            time_zone::america::RAW_NIPIGON,
            &[
                "America/Nipigon",
                "america/nipigon",
                "AMERICA/NIPIGON",
                "aMERICA/nIPIGON",
                "AmErIcA/NiPiGoN",
                "aMeRiCa/nIpIgOn",
            ],
        ),
        (
            time_zone::america::THUNDER_BAY,
            time_zone::america::RAW_THUNDER_BAY,
            &[
                "America/Thunder_Bay",
                "america/thunder_bay",
                "AMERICA/THUNDER_BAY",
                "aMERICA/tHUNDER_bAY",
                "AmErIcA/ThUnDeR_BaY",
                "aMeRiCa/tHuNdEr_bAy",
            ],
        ),
        (
            time_zone::america::TORONTO,
            time_zone::america::RAW_TORONTO,
            &[
                "America/Toronto",
                "america/toronto",
                "AMERICA/TORONTO",
                "aMERICA/tORONTO",
                "AmErIcA/ToRoNtO",
                "aMeRiCa/tOrOnTo",
            ],
        ),
        (
            time_zone::canada::EASTERN,
            time_zone::canada::RAW_EASTERN,
            &[
                "Canada/Eastern",
                "canada/eastern",
                "CANADA/EASTERN",
                "cANADA/eASTERN",
                "CaNaDa/eAsTeRn",
                "cAnAdA/EaStErN",
            ],
        ),
        (
            time_zone::america::MONTSERRAT,
            time_zone::america::RAW_MONTSERRAT,
            &[
                "America/Montserrat",
                "america/montserrat",
                "AMERICA/MONTSERRAT",
                "aMERICA/mONTSERRAT",
                "AmErIcA/MoNtSeRrAt",
                "aMeRiCa/mOnTsErRaT",
            ],
        ),
        (
            time_zone::america::NASSAU,
            time_zone::america::RAW_NASSAU,
            &[
                "America/Nassau",
                "america/nassau",
                "AMERICA/NASSAU",
                "aMERICA/nASSAU",
                "AmErIcA/NaSsAu",
                "aMeRiCa/nAsSaU",
            ],
        ),
        (
            time_zone::america::NEW_YORK,
            time_zone::america::RAW_NEW_YORK,
            &[
                "America/New_York",
                "america/new_york",
                "AMERICA/NEW_YORK",
                "aMERICA/nEW_yORK",
                "AmErIcA/NeW_YoRk",
                "aMeRiCa/nEw_yOrK",
            ],
        ),
        (time_zone::us::EASTERN, time_zone::us::RAW_EASTERN, &[
            "US/Eastern",
            "us/eastern",
            "US/EASTERN",
            "us/eASTERN",
            "Us/eAsTeRn",
            "uS/EaStErN",
        ]),
        (time_zone::america::NOME, time_zone::america::RAW_NOME, &[
            "America/Nome",
            "america/nome",
            "AMERICA/NOME",
            "aMERICA/nOME",
            "AmErIcA/NoMe",
            "aMeRiCa/nOmE",
        ]),
        (
            time_zone::america::NORONHA,
            time_zone::america::RAW_NORONHA,
            &[
                "America/Noronha",
                "america/noronha",
                "AMERICA/NORONHA",
                "aMERICA/nORONHA",
                "AmErIcA/NoRoNhA",
                "aMeRiCa/nOrOnHa",
            ],
        ),
        (
            time_zone::brazil::DE_NORONHA,
            time_zone::brazil::RAW_DE_NORONHA,
            &[
                "Brazil/DeNoronha",
                "brazil/denoronha",
                "BRAZIL/DENORONHA",
                "bRAZIL/dEnORONHA",
                "BrAzIl/dEnOrOnHa",
                "bRaZiL/DeNoRoNhA",
            ],
        ),
        (
            time_zone::america::PARAMARIBO,
            time_zone::america::RAW_PARAMARIBO,
            &[
                "America/Paramaribo",
                "america/paramaribo",
                "AMERICA/PARAMARIBO",
                "aMERICA/pARAMARIBO",
                "AmErIcA/PaRaMaRiBo",
                "aMeRiCa/pArAmArIbO",
            ],
        ),
        (
            time_zone::america::PHOENIX,
            time_zone::america::RAW_PHOENIX,
            &[
                "America/Phoenix",
                "america/phoenix",
                "AMERICA/PHOENIX",
                "aMERICA/pHOENIX",
                "AmErIcA/PhOeNiX",
                "aMeRiCa/pHoEnIx",
            ],
        ),
        (time_zone::us::ARIZONA, time_zone::us::RAW_ARIZONA, &[
            "US/Arizona",
            "us/arizona",
            "US/ARIZONA",
            "us/aRIZONA",
            "Us/aRiZoNa",
            "uS/ArIzOnA",
        ]),
        (
            time_zone::america::PORTO_ACRE,
            time_zone::america::RAW_PORTO_ACRE,
            &[
                "America/Porto_Acre",
                "america/porto_acre",
                "AMERICA/PORTO_ACRE",
                "aMERICA/pORTO_aCRE",
                "AmErIcA/PoRtO_AcRe",
                "aMeRiCa/pOrTo_aCrE",
            ],
        ),
        (
            time_zone::america::RIO_BRANCO,
            time_zone::america::RAW_RIO_BRANCO,
            &[
                "America/Rio_Branco",
                "america/rio_branco",
                "AMERICA/RIO_BRANCO",
                "aMERICA/rIO_bRANCO",
                "AmErIcA/RiO_BrAnCo",
                "aMeRiCa/rIo_bRaNcO",
            ],
        ),
        (time_zone::brazil::ACRE, time_zone::brazil::RAW_ACRE, &[
            "Brazil/Acre",
            "brazil/acre",
            "BRAZIL/ACRE",
            "bRAZIL/aCRE",
            "BrAzIl/aCrE",
            "bRaZiL/AcRe",
        ]),
        (
            time_zone::america::PORTO_VELHO,
            time_zone::america::RAW_PORTO_VELHO,
            &[
                "America/Porto_Velho",
                "america/porto_velho",
                "AMERICA/PORTO_VELHO",
                "aMERICA/pORTO_vELHO",
                "AmErIcA/PoRtO_VeLhO",
                "aMeRiCa/pOrTo_vElHo",
            ],
        ),
        (
            time_zone::america::PORT_AU_PRINCE,
            time_zone::america::RAW_PORT_AU_PRINCE,
            &[
                "America/Port-au-Prince",
                "america/port-au-prince",
                "AMERICA/PORT-AU-PRINCE",
                "aMERICA/pORT-AU-pRINCE",
                "AmErIcA/PoRt-aU-PrInCe",
                "aMeRiCa/pOrT-Au-pRiNcE",
            ],
        ),
        (
            time_zone::america::PORT_OF_SPAIN,
            time_zone::america::RAW_PORT_OF_SPAIN,
            &[
                "America/Port_of_Spain",
                "america/port_of_spain",
                "AMERICA/PORT_OF_SPAIN",
                "aMERICA/pORT_OF_sPAIN",
                "AmErIcA/PoRt_oF_SpAiN",
                "aMeRiCa/pOrT_Of_sPaIn",
            ],
        ),
        (
            time_zone::america::PUNTA_ARENAS,
            time_zone::america::RAW_PUNTA_ARENAS,
            &[
                "America/Punta_Arenas",
                "america/punta_arenas",
                "AMERICA/PUNTA_ARENAS",
                "aMERICA/pUNTA_aRENAS",
                "AmErIcA/PuNtA_ArEnAs",
                "aMeRiCa/pUnTa_aReNaS",
            ],
        ),
        (
            time_zone::america::RAINY_RIVER,
            time_zone::america::RAW_RAINY_RIVER,
            &[
                "America/Rainy_River",
                "america/rainy_river",
                "AMERICA/RAINY_RIVER",
                "aMERICA/rAINY_rIVER",
                "AmErIcA/RaInY_RiVeR",
                "aMeRiCa/rAiNy_rIvEr",
            ],
        ),
        (
            time_zone::america::WINNIPEG,
            time_zone::america::RAW_WINNIPEG,
            &[
                "America/Winnipeg",
                "america/winnipeg",
                "AMERICA/WINNIPEG",
                "aMERICA/wINNIPEG",
                "AmErIcA/WiNnIpEg",
                "aMeRiCa/wInNiPeG",
            ],
        ),
        (
            time_zone::canada::CENTRAL,
            time_zone::canada::RAW_CENTRAL,
            &[
                "Canada/Central",
                "canada/central",
                "CANADA/CENTRAL",
                "cANADA/cENTRAL",
                "CaNaDa/cEnTrAl",
                "cAnAdA/CeNtRaL",
            ],
        ),
        (
            time_zone::america::RANKIN_INLET,
            time_zone::america::RAW_RANKIN_INLET,
            &[
                "America/Rankin_Inlet",
                "america/rankin_inlet",
                "AMERICA/RANKIN_INLET",
                "aMERICA/rANKIN_iNLET",
                "AmErIcA/RaNkIn_iNlEt",
                "aMeRiCa/rAnKiN_InLeT",
            ],
        ),
        (
            time_zone::america::RECIFE,
            time_zone::america::RAW_RECIFE,
            &[
                "America/Recife",
                "america/recife",
                "AMERICA/RECIFE",
                "aMERICA/rECIFE",
                "AmErIcA/ReCiFe",
                "aMeRiCa/rEcIfE",
            ],
        ),
        (
            time_zone::america::REGINA,
            time_zone::america::RAW_REGINA,
            &[
                "America/Regina",
                "america/regina",
                "AMERICA/REGINA",
                "aMERICA/rEGINA",
                "AmErIcA/ReGiNa",
                "aMeRiCa/rEgInA",
            ],
        ),
        (
            time_zone::canada::SASKATCHEWAN,
            time_zone::canada::RAW_SASKATCHEWAN,
            &[
                "Canada/Saskatchewan",
                "canada/saskatchewan",
                "CANADA/SASKATCHEWAN",
                "cANADA/sASKATCHEWAN",
                "CaNaDa/sAsKaTcHeWaN",
                "cAnAdA/SaSkAtChEwAn",
            ],
        ),
        (
            time_zone::america::RESOLUTE,
            time_zone::america::RAW_RESOLUTE,
            &[
                "America/Resolute",
                "america/resolute",
                "AMERICA/RESOLUTE",
                "aMERICA/rESOLUTE",
                "AmErIcA/ReSoLuTe",
                "aMeRiCa/rEsOlUtE",
            ],
        ),
        (
            time_zone::america::SANTAREM,
            time_zone::america::RAW_SANTAREM,
            &[
                "America/Santarem",
                "america/santarem",
                "AMERICA/SANTAREM",
                "aMERICA/sANTAREM",
                "AmErIcA/SaNtArEm",
                "aMeRiCa/sAnTaReM",
            ],
        ),
        (
            time_zone::america::SANTIAGO,
            time_zone::america::RAW_SANTIAGO,
            &[
                "America/Santiago",
                "america/santiago",
                "AMERICA/SANTIAGO",
                "aMERICA/sANTIAGO",
                "AmErIcA/SaNtIaGo",
                "aMeRiCa/sAnTiAgO",
            ],
        ),
        (
            time_zone::chile::CONTINENTAL,
            time_zone::chile::RAW_CONTINENTAL,
            &[
                "Chile/Continental",
                "chile/continental",
                "CHILE/CONTINENTAL",
                "cHILE/cONTINENTAL",
                "ChIlE/CoNtInEnTaL",
                "cHiLe/cOnTiNeNtAl",
            ],
        ),
        (
            time_zone::america::SANTO_DOMINGO,
            time_zone::america::RAW_SANTO_DOMINGO,
            &[
                "America/Santo_Domingo",
                "america/santo_domingo",
                "AMERICA/SANTO_DOMINGO",
                "aMERICA/sANTO_dOMINGO",
                "AmErIcA/SaNtO_DoMiNgO",
                "aMeRiCa/sAnTo_dOmInGo",
            ],
        ),
        (
            time_zone::america::SAO_PAULO,
            time_zone::america::RAW_SAO_PAULO,
            &[
                "America/Sao_Paulo",
                "america/sao_paulo",
                "AMERICA/SAO_PAULO",
                "aMERICA/sAO_pAULO",
                "AmErIcA/SaO_PaUlO",
                "aMeRiCa/sAo_pAuLo",
            ],
        ),
        (time_zone::brazil::EAST, time_zone::brazil::RAW_EAST, &[
            "Brazil/East",
            "brazil/east",
            "BRAZIL/EAST",
            "bRAZIL/eAST",
            "BrAzIl/eAsT",
            "bRaZiL/EaSt",
        ]),
        (
            time_zone::america::SCORESBYSUND,
            time_zone::america::RAW_SCORESBYSUND,
            &[
                "America/Scoresbysund",
                "america/scoresbysund",
                "AMERICA/SCORESBYSUND",
                "aMERICA/sCORESBYSUND",
                "AmErIcA/ScOrEsBySuNd",
                "aMeRiCa/sCoReSbYsUnD",
            ],
        ),
        (time_zone::america::SITKA, time_zone::america::RAW_SITKA, &[
            "America/Sitka",
            "america/sitka",
            "AMERICA/SITKA",
            "aMERICA/sITKA",
            "AmErIcA/SiTkA",
            "aMeRiCa/sItKa",
        ]),
        (
            time_zone::america::ST_JOHNS,
            time_zone::america::RAW_ST_JOHNS,
            &[
                "America/St_Johns",
                "america/st_johns",
                "AMERICA/ST_JOHNS",
                "aMERICA/sT_jOHNS",
                "AmErIcA/St_jOhNs",
                "aMeRiCa/sT_JoHnS",
            ],
        ),
        (
            time_zone::canada::NEWFOUNDLAND,
            time_zone::canada::RAW_NEWFOUNDLAND,
            &[
                "Canada/Newfoundland",
                "canada/newfoundland",
                "CANADA/NEWFOUNDLAND",
                "cANADA/nEWFOUNDLAND",
                "CaNaDa/nEwFoUnDlAnD",
                "cAnAdA/NeWfOuNdLaNd",
            ],
        ),
        (
            time_zone::america::ST_KITTS,
            time_zone::america::RAW_ST_KITTS,
            &[
                "America/St_Kitts",
                "america/st_kitts",
                "AMERICA/ST_KITTS",
                "aMERICA/sT_kITTS",
                "AmErIcA/St_kItTs",
                "aMeRiCa/sT_KiTtS",
            ],
        ),
        (
            time_zone::america::ST_LUCIA,
            time_zone::america::RAW_ST_LUCIA,
            &[
                "America/St_Lucia",
                "america/st_lucia",
                "AMERICA/ST_LUCIA",
                "aMERICA/sT_lUCIA",
                "AmErIcA/St_lUcIa",
                "aMeRiCa/sT_LuCiA",
            ],
        ),
        (
            time_zone::america::ST_THOMAS,
            time_zone::america::RAW_ST_THOMAS,
            &[
                "America/St_Thomas",
                "america/st_thomas",
                "AMERICA/ST_THOMAS",
                "aMERICA/sT_tHOMAS",
                "AmErIcA/St_tHoMaS",
                "aMeRiCa/sT_ThOmAs",
            ],
        ),
        (
            time_zone::america::ST_VINCENT,
            time_zone::america::RAW_ST_VINCENT,
            &[
                "America/St_Vincent",
                "america/st_vincent",
                "AMERICA/ST_VINCENT",
                "aMERICA/sT_vINCENT",
                "AmErIcA/St_vInCeNt",
                "aMeRiCa/sT_ViNcEnT",
            ],
        ),
        (
            time_zone::america::SWIFT_CURRENT,
            time_zone::america::RAW_SWIFT_CURRENT,
            &[
                "America/Swift_Current",
                "america/swift_current",
                "AMERICA/SWIFT_CURRENT",
                "aMERICA/sWIFT_cURRENT",
                "AmErIcA/SwIfT_CuRrEnT",
                "aMeRiCa/sWiFt_cUrReNt",
            ],
        ),
        (
            time_zone::america::TEGUCIGALPA,
            time_zone::america::RAW_TEGUCIGALPA,
            &[
                "America/Tegucigalpa",
                "america/tegucigalpa",
                "AMERICA/TEGUCIGALPA",
                "aMERICA/tEGUCIGALPA",
                "AmErIcA/TeGuCiGaLpA",
                "aMeRiCa/tEgUcIgAlPa",
            ],
        ),
        (time_zone::america::THULE, time_zone::america::RAW_THULE, &[
            "America/Thule",
            "america/thule",
            "AMERICA/THULE",
            "aMERICA/tHULE",
            "AmErIcA/ThUlE",
            "aMeRiCa/tHuLe",
        ]),
        (
            time_zone::america::TORTOLA,
            time_zone::america::RAW_TORTOLA,
            &[
                "America/Tortola",
                "america/tortola",
                "AMERICA/TORTOLA",
                "aMERICA/tORTOLA",
                "AmErIcA/ToRtOlA",
                "aMeRiCa/tOrToLa",
            ],
        ),
        (
            time_zone::america::VANCOUVER,
            time_zone::america::RAW_VANCOUVER,
            &[
                "America/Vancouver",
                "america/vancouver",
                "AMERICA/VANCOUVER",
                "aMERICA/vANCOUVER",
                "AmErIcA/VaNcOuVeR",
                "aMeRiCa/vAnCoUvEr",
            ],
        ),
        (
            time_zone::canada::PACIFIC,
            time_zone::canada::RAW_PACIFIC,
            &[
                "Canada/Pacific",
                "canada/pacific",
                "CANADA/PACIFIC",
                "cANADA/pACIFIC",
                "CaNaDa/pAcIfIc",
                "cAnAdA/PaCiFiC",
            ],
        ),
        (
            time_zone::america::WHITEHORSE,
            time_zone::america::RAW_WHITEHORSE,
            &[
                "America/Whitehorse",
                "america/whitehorse",
                "AMERICA/WHITEHORSE",
                "aMERICA/wHITEHORSE",
                "AmErIcA/WhItEhOrSe",
                "aMeRiCa/wHiTeHoRsE",
            ],
        ),
        (time_zone::canada::YUKON, time_zone::canada::RAW_YUKON, &[
            "Canada/Yukon",
            "canada/yukon",
            "CANADA/YUKON",
            "cANADA/yUKON",
            "CaNaDa/yUkOn",
            "cAnAdA/YuKoN",
        ]),
        (
            time_zone::america::YAKUTAT,
            time_zone::america::RAW_YAKUTAT,
            &[
                "America/Yakutat",
                "america/yakutat",
                "AMERICA/YAKUTAT",
                "aMERICA/yAKUTAT",
                "AmErIcA/YaKuTaT",
                "aMeRiCa/yAkUtAt",
            ],
        ),
        (
            time_zone::antarctica::CASEY,
            time_zone::antarctica::RAW_CASEY,
            &[
                "Antarctica/Casey",
                "antarctica/casey",
                "ANTARCTICA/CASEY",
                "aNTARCTICA/cASEY",
                "AnTaRcTiCa/cAsEy",
                "aNtArCtIcA/CaSeY",
            ],
        ),
        (
            time_zone::antarctica::DAVIS,
            time_zone::antarctica::RAW_DAVIS,
            &[
                "Antarctica/Davis",
                "antarctica/davis",
                "ANTARCTICA/DAVIS",
                "aNTARCTICA/dAVIS",
                "AnTaRcTiCa/dAvIs",
                "aNtArCtIcA/DaViS",
            ],
        ),
        (
            time_zone::antarctica::DUMONT_D_URVILLE,
            time_zone::antarctica::RAW_DUMONT_D_URVILLE,
            &[
                "Antarctica/DumontDUrville",
                "antarctica/dumontdurville",
                "ANTARCTICA/DUMONTDURVILLE",
                "aNTARCTICA/dUMONTduRVILLE",
                "AnTaRcTiCa/dUmOnTdUrViLlE",
                "aNtArCtIcA/DuMoNtDuRvIlLe",
            ],
        ),
        (
            time_zone::antarctica::MACQUARIE,
            time_zone::antarctica::RAW_MACQUARIE,
            &[
                "Antarctica/Macquarie",
                "antarctica/macquarie",
                "ANTARCTICA/MACQUARIE",
                "aNTARCTICA/mACQUARIE",
                "AnTaRcTiCa/mAcQuArIe",
                "aNtArCtIcA/MaCqUaRiE",
            ],
        ),
        (
            time_zone::antarctica::MAWSON,
            time_zone::antarctica::RAW_MAWSON,
            &[
                "Antarctica/Mawson",
                "antarctica/mawson",
                "ANTARCTICA/MAWSON",
                "aNTARCTICA/mAWSON",
                "AnTaRcTiCa/mAwSoN",
                "aNtArCtIcA/MaWsOn",
            ],
        ),
        (
            time_zone::antarctica::MC_MURDO,
            time_zone::antarctica::RAW_MC_MURDO,
            &[
                "Antarctica/McMurdo",
                "antarctica/mcmurdo",
                "ANTARCTICA/MCMURDO",
                "aNTARCTICA/mCmURDO",
                "AnTaRcTiCa/mCmUrDo",
                "aNtArCtIcA/McMuRdO",
            ],
        ),
        (
            time_zone::antarctica::PALMER,
            time_zone::antarctica::RAW_PALMER,
            &[
                "Antarctica/Palmer",
                "antarctica/palmer",
                "ANTARCTICA/PALMER",
                "aNTARCTICA/pALMER",
                "AnTaRcTiCa/pAlMeR",
                "aNtArCtIcA/PaLmEr",
            ],
        ),
        (
            time_zone::antarctica::ROTHERA,
            time_zone::antarctica::RAW_ROTHERA,
            &[
                "Antarctica/Rothera",
                "antarctica/rothera",
                "ANTARCTICA/ROTHERA",
                "aNTARCTICA/rOTHERA",
                "AnTaRcTiCa/rOtHeRa",
                "aNtArCtIcA/RoThErA",
            ],
        ),
        (
            time_zone::antarctica::SYOWA,
            time_zone::antarctica::RAW_SYOWA,
            &[
                "Antarctica/Syowa",
                "antarctica/syowa",
                "ANTARCTICA/SYOWA",
                "aNTARCTICA/sYOWA",
                "AnTaRcTiCa/sYoWa",
                "aNtArCtIcA/SyOwA",
            ],
        ),
        (
            time_zone::antarctica::TROLL,
            time_zone::antarctica::RAW_TROLL,
            &[
                "Antarctica/Troll",
                "antarctica/troll",
                "ANTARCTICA/TROLL",
                "aNTARCTICA/tROLL",
                "AnTaRcTiCa/tRoLl",
                "aNtArCtIcA/TrOlL",
            ],
        ),
        (
            time_zone::antarctica::VOSTOK,
            time_zone::antarctica::RAW_VOSTOK,
            &[
                "Antarctica/Vostok",
                "antarctica/vostok",
                "ANTARCTICA/VOSTOK",
                "aNTARCTICA/vOSTOK",
                "AnTaRcTiCa/vOsToK",
                "aNtArCtIcA/VoStOk",
            ],
        ),
        (
            time_zone::arctic::LONGYEARBYEN,
            time_zone::arctic::RAW_LONGYEARBYEN,
            &[
                "Arctic/Longyearbyen",
                "arctic/longyearbyen",
                "ARCTIC/LONGYEARBYEN",
                "aRCTIC/lONGYEARBYEN",
                "ArCtIc/lOnGyEaRbYeN",
                "aRcTiC/LoNgYeArByEn",
            ],
        ),
        (
            time_zone::atlantic::JAN_MAYEN,
            time_zone::atlantic::RAW_JAN_MAYEN,
            &[
                "Atlantic/Jan_Mayen",
                "atlantic/jan_mayen",
                "ATLANTIC/JAN_MAYEN",
                "aTLANTIC/jAN_mAYEN",
                "AtLaNtIc/jAn_mAyEn",
                "aTlAnTiC/JaN_MaYeN",
            ],
        ),
        (time_zone::europe::BERLIN, time_zone::europe::RAW_BERLIN, &[
            "Europe/Berlin",
            "europe/berlin",
            "EUROPE/BERLIN",
            "eUROPE/bERLIN",
            "EuRoPe/bErLiN",
            "eUrOpE/BeRlIn",
        ]),
        (time_zone::asia::ADEN, time_zone::asia::RAW_ADEN, &[
            "Asia/Aden",
            "asia/aden",
            "ASIA/ADEN",
            "aSIA/aDEN",
            "AsIa/aDeN",
            "aSiA/AdEn",
        ]),
        (time_zone::asia::ALMATY, time_zone::asia::RAW_ALMATY, &[
            "Asia/Almaty",
            "asia/almaty",
            "ASIA/ALMATY",
            "aSIA/aLMATY",
            "AsIa/aLmAtY",
            "aSiA/AlMaTy",
        ]),
        (time_zone::asia::AMMAN, time_zone::asia::RAW_AMMAN, &[
            "Asia/Amman",
            "asia/amman",
            "ASIA/AMMAN",
            "aSIA/aMMAN",
            "AsIa/aMmAn",
            "aSiA/AmMaN",
        ]),
        (time_zone::asia::ANADYR, time_zone::asia::RAW_ANADYR, &[
            "Asia/Anadyr",
            "asia/anadyr",
            "ASIA/ANADYR",
            "aSIA/aNADYR",
            "AsIa/aNaDyR",
            "aSiA/AnAdYr",
        ]),
        (time_zone::asia::AQTAU, time_zone::asia::RAW_AQTAU, &[
            "Asia/Aqtau",
            "asia/aqtau",
            "ASIA/AQTAU",
            "aSIA/aQTAU",
            "AsIa/aQtAu",
            "aSiA/AqTaU",
        ]),
        (time_zone::asia::AQTOBE, time_zone::asia::RAW_AQTOBE, &[
            "Asia/Aqtobe",
            "asia/aqtobe",
            "ASIA/AQTOBE",
            "aSIA/aQTOBE",
            "AsIa/aQtObE",
            "aSiA/AqToBe",
        ]),
        (time_zone::asia::ASHGABAT, time_zone::asia::RAW_ASHGABAT, &[
            "Asia/Ashgabat",
            "asia/ashgabat",
            "ASIA/ASHGABAT",
            "aSIA/aSHGABAT",
            "AsIa/aShGaBaT",
            "aSiA/AsHgAbAt",
        ]),
        (
            time_zone::asia::ASHKHABAD,
            time_zone::asia::RAW_ASHKHABAD,
            &[
                "Asia/Ashkhabad",
                "asia/ashkhabad",
                "ASIA/ASHKHABAD",
                "aSIA/aSHKHABAD",
                "AsIa/aShKhAbAd",
                "aSiA/AsHkHaBaD",
            ],
        ),
        (time_zone::asia::ATYRAU, time_zone::asia::RAW_ATYRAU, &[
            "Asia/Atyrau",
            "asia/atyrau",
            "ASIA/ATYRAU",
            "aSIA/aTYRAU",
            "AsIa/aTyRaU",
            "aSiA/AtYrAu",
        ]),
        (time_zone::asia::BAGHDAD, time_zone::asia::RAW_BAGHDAD, &[
            "Asia/Baghdad",
            "asia/baghdad",
            "ASIA/BAGHDAD",
            "aSIA/bAGHDAD",
            "AsIa/bAgHdAd",
            "aSiA/BaGhDaD",
        ]),
        (time_zone::asia::BAHRAIN, time_zone::asia::RAW_BAHRAIN, &[
            "Asia/Bahrain",
            "asia/bahrain",
            "ASIA/BAHRAIN",
            "aSIA/bAHRAIN",
            "AsIa/bAhRaIn",
            "aSiA/BaHrAiN",
        ]),
        (time_zone::asia::BAKU, time_zone::asia::RAW_BAKU, &[
            "Asia/Baku",
            "asia/baku",
            "ASIA/BAKU",
            "aSIA/bAKU",
            "AsIa/bAkU",
            "aSiA/BaKu",
        ]),
        (time_zone::asia::BANGKOK, time_zone::asia::RAW_BANGKOK, &[
            "Asia/Bangkok",
            "asia/bangkok",
            "ASIA/BANGKOK",
            "aSIA/bANGKOK",
            "AsIa/bAnGkOk",
            "aSiA/BaNgKoK",
        ]),
        (time_zone::asia::BARNAUL, time_zone::asia::RAW_BARNAUL, &[
            "Asia/Barnaul",
            "asia/barnaul",
            "ASIA/BARNAUL",
            "aSIA/bARNAUL",
            "AsIa/bArNaUl",
            "aSiA/BaRnAuL",
        ]),
        (time_zone::asia::BEIRUT, time_zone::asia::RAW_BEIRUT, &[
            "Asia/Beirut",
            "asia/beirut",
            "ASIA/BEIRUT",
            "aSIA/bEIRUT",
            "AsIa/bEiRuT",
            "aSiA/BeIrUt",
        ]),
        (time_zone::asia::BISHKEK, time_zone::asia::RAW_BISHKEK, &[
            "Asia/Bishkek",
            "asia/bishkek",
            "ASIA/BISHKEK",
            "aSIA/bISHKEK",
            "AsIa/bIsHkEk",
            "aSiA/BiShKeK",
        ]),
        (time_zone::asia::BRUNEI, time_zone::asia::RAW_BRUNEI, &[
            "Asia/Brunei",
            "asia/brunei",
            "ASIA/BRUNEI",
            "aSIA/bRUNEI",
            "AsIa/bRuNeI",
            "aSiA/BrUnEi",
        ]),
        (time_zone::asia::CALCUTTA, time_zone::asia::RAW_CALCUTTA, &[
            "Asia/Calcutta",
            "asia/calcutta",
            "ASIA/CALCUTTA",
            "aSIA/cALCUTTA",
            "AsIa/cAlCuTtA",
            "aSiA/CaLcUtTa",
        ]),
        (time_zone::asia::KOLKATA, time_zone::asia::RAW_KOLKATA, &[
            "Asia/Kolkata",
            "asia/kolkata",
            "ASIA/KOLKATA",
            "aSIA/kOLKATA",
            "AsIa/kOlKaTa",
            "aSiA/KoLkAtA",
        ]),
        (time_zone::asia::CHITA, time_zone::asia::RAW_CHITA, &[
            "Asia/Chita",
            "asia/chita",
            "ASIA/CHITA",
            "aSIA/cHITA",
            "AsIa/cHiTa",
            "aSiA/ChItA",
        ]),
        (
            time_zone::asia::CHOIBALSAN,
            time_zone::asia::RAW_CHOIBALSAN,
            &[
                "Asia/Choibalsan",
                "asia/choibalsan",
                "ASIA/CHOIBALSAN",
                "aSIA/cHOIBALSAN",
                "AsIa/cHoIbAlSaN",
                "aSiA/ChOiBaLsAn",
            ],
        ),
        (time_zone::asia::COLOMBO, time_zone::asia::RAW_COLOMBO, &[
            "Asia/Colombo",
            "asia/colombo",
            "ASIA/COLOMBO",
            "aSIA/cOLOMBO",
            "AsIa/cOlOmBo",
            "aSiA/CoLoMbO",
        ]),
        (time_zone::asia::DACCA, time_zone::asia::RAW_DACCA, &[
            "Asia/Dacca",
            "asia/dacca",
            "ASIA/DACCA",
            "aSIA/dACCA",
            "AsIa/dAcCa",
            "aSiA/DaCcA",
        ]),
        (time_zone::asia::DHAKA, time_zone::asia::RAW_DHAKA, &[
            "Asia/Dhaka",
            "asia/dhaka",
            "ASIA/DHAKA",
            "aSIA/dHAKA",
            "AsIa/dHaKa",
            "aSiA/DhAkA",
        ]),
        (time_zone::asia::DAMASCUS, time_zone::asia::RAW_DAMASCUS, &[
            "Asia/Damascus",
            "asia/damascus",
            "ASIA/DAMASCUS",
            "aSIA/dAMASCUS",
            "AsIa/dAmAsCuS",
            "aSiA/DaMaScUs",
        ]),
        (time_zone::asia::DILI, time_zone::asia::RAW_DILI, &[
            "Asia/Dili",
            "asia/dili",
            "ASIA/DILI",
            "aSIA/dILI",
            "AsIa/dIlI",
            "aSiA/DiLi",
        ]),
        (time_zone::asia::DUBAI, time_zone::asia::RAW_DUBAI, &[
            "Asia/Dubai",
            "asia/dubai",
            "ASIA/DUBAI",
            "aSIA/dUBAI",
            "AsIa/dUbAi",
            "aSiA/DuBaI",
        ]),
        (time_zone::asia::DUSHANBE, time_zone::asia::RAW_DUSHANBE, &[
            "Asia/Dushanbe",
            "asia/dushanbe",
            "ASIA/DUSHANBE",
            "aSIA/dUSHANBE",
            "AsIa/dUsHaNbE",
            "aSiA/DuShAnBe",
        ]),
        (
            time_zone::asia::FAMAGUSTA,
            time_zone::asia::RAW_FAMAGUSTA,
            &[
                "Asia/Famagusta",
                "asia/famagusta",
                "ASIA/FAMAGUSTA",
                "aSIA/fAMAGUSTA",
                "AsIa/fAmAgUsTa",
                "aSiA/FaMaGuStA",
            ],
        ),
        (time_zone::asia::GAZA, time_zone::asia::RAW_GAZA, &[
            "Asia/Gaza",
            "asia/gaza",
            "ASIA/GAZA",
            "aSIA/gAZA",
            "AsIa/gAzA",
            "aSiA/GaZa",
        ]),
        (time_zone::asia::HEBRON, time_zone::asia::RAW_HEBRON, &[
            "Asia/Hebron",
            "asia/hebron",
            "ASIA/HEBRON",
            "aSIA/hEBRON",
            "AsIa/hEbRoN",
            "aSiA/HeBrOn",
        ]),
        (time_zone::asia::HOVD, time_zone::asia::RAW_HOVD, &[
            "Asia/Hovd",
            "asia/hovd",
            "ASIA/HOVD",
            "aSIA/hOVD",
            "AsIa/hOvD",
            "aSiA/HoVd",
        ]),
        (
            time_zone::asia::HO_CHI_MINH,
            time_zone::asia::RAW_HO_CHI_MINH,
            &[
                "Asia/Ho_Chi_Minh",
                "asia/ho_chi_minh",
                "ASIA/HO_CHI_MINH",
                "aSIA/hO_cHI_mINH",
                "AsIa/hO_ChI_MiNh",
                "aSiA/Ho_cHi_mInH",
            ],
        ),
        (time_zone::asia::SAIGON, time_zone::asia::RAW_SAIGON, &[
            "Asia/Saigon",
            "asia/saigon",
            "ASIA/SAIGON",
            "aSIA/sAIGON",
            "AsIa/sAiGoN",
            "aSiA/SaIgOn",
        ]),
        (time_zone::asia::IRKUTSK, time_zone::asia::RAW_IRKUTSK, &[
            "Asia/Irkutsk",
            "asia/irkutsk",
            "ASIA/IRKUTSK",
            "aSIA/iRKUTSK",
            "AsIa/iRkUtSk",
            "aSiA/IrKuTsK",
        ]),
        (time_zone::asia::JAKARTA, time_zone::asia::RAW_JAKARTA, &[
            "Asia/Jakarta",
            "asia/jakarta",
            "ASIA/JAKARTA",
            "aSIA/jAKARTA",
            "AsIa/jAkArTa",
            "aSiA/JaKaRtA",
        ]),
        (time_zone::asia::JAYAPURA, time_zone::asia::RAW_JAYAPURA, &[
            "Asia/Jayapura",
            "asia/jayapura",
            "ASIA/JAYAPURA",
            "aSIA/jAYAPURA",
            "AsIa/jAyApUrA",
            "aSiA/JaYaPuRa",
        ]),
        (time_zone::asia::KABUL, time_zone::asia::RAW_KABUL, &[
            "Asia/Kabul",
            "asia/kabul",
            "ASIA/KABUL",
            "aSIA/kABUL",
            "AsIa/kAbUl",
            "aSiA/KaBuL",
        ]),
        (
            time_zone::asia::KAMCHATKA,
            time_zone::asia::RAW_KAMCHATKA,
            &[
                "Asia/Kamchatka",
                "asia/kamchatka",
                "ASIA/KAMCHATKA",
                "aSIA/kAMCHATKA",
                "AsIa/kAmChAtKa",
                "aSiA/KaMcHaTkA",
            ],
        ),
        (time_zone::asia::KARACHI, time_zone::asia::RAW_KARACHI, &[
            "Asia/Karachi",
            "asia/karachi",
            "ASIA/KARACHI",
            "aSIA/kARACHI",
            "AsIa/kArAcHi",
            "aSiA/KaRaChI",
        ]),
        (time_zone::asia::KASHGAR, time_zone::asia::RAW_KASHGAR, &[
            "Asia/Kashgar",
            "asia/kashgar",
            "ASIA/KASHGAR",
            "aSIA/kASHGAR",
            "AsIa/kAsHgAr",
            "aSiA/KaShGaR",
        ]),
        (time_zone::asia::URUMQI, time_zone::asia::RAW_URUMQI, &[
            "Asia/Urumqi",
            "asia/urumqi",
            "ASIA/URUMQI",
            "aSIA/uRUMQI",
            "AsIa/uRuMqI",
            "aSiA/UrUmQi",
        ]),
        (
            time_zone::asia::KATHMANDU,
            time_zone::asia::RAW_KATHMANDU,
            &[
                "Asia/Kathmandu",
                "asia/kathmandu",
                "ASIA/KATHMANDU",
                "aSIA/kATHMANDU",
                "AsIa/kAtHmAnDu",
                "aSiA/KaThMaNdU",
            ],
        ),
        (time_zone::asia::KATMANDU, time_zone::asia::RAW_KATMANDU, &[
            "Asia/Katmandu",
            "asia/katmandu",
            "ASIA/KATMANDU",
            "aSIA/kATMANDU",
            "AsIa/kAtMaNdU",
            "aSiA/KaTmAnDu",
        ]),
        (time_zone::asia::KHANDYGA, time_zone::asia::RAW_KHANDYGA, &[
            "Asia/Khandyga",
            "asia/khandyga",
            "ASIA/KHANDYGA",
            "aSIA/kHANDYGA",
            "AsIa/kHaNdYgA",
            "aSiA/KhAnDyGa",
        ]),
        (
            time_zone::asia::KRASNOYARSK,
            time_zone::asia::RAW_KRASNOYARSK,
            &[
                "Asia/Krasnoyarsk",
                "asia/krasnoyarsk",
                "ASIA/KRASNOYARSK",
                "aSIA/kRASNOYARSK",
                "AsIa/kRaSnOyArSk",
                "aSiA/KrAsNoYaRsK",
            ],
        ),
        (
            time_zone::asia::KUALA_LUMPUR,
            time_zone::asia::RAW_KUALA_LUMPUR,
            &[
                "Asia/Kuala_Lumpur",
                "asia/kuala_lumpur",
                "ASIA/KUALA_LUMPUR",
                "aSIA/kUALA_lUMPUR",
                "AsIa/kUaLa_lUmPuR",
                "aSiA/KuAlA_LuMpUr",
            ],
        ),
        (time_zone::asia::KUCHING, time_zone::asia::RAW_KUCHING, &[
            "Asia/Kuching",
            "asia/kuching",
            "ASIA/KUCHING",
            "aSIA/kUCHING",
            "AsIa/kUcHiNg",
            "aSiA/KuChInG",
        ]),
        (time_zone::asia::KUWAIT, time_zone::asia::RAW_KUWAIT, &[
            "Asia/Kuwait",
            "asia/kuwait",
            "ASIA/KUWAIT",
            "aSIA/kUWAIT",
            "AsIa/kUwAiT",
            "aSiA/KuWaIt",
        ]),
        (time_zone::asia::MACAO, time_zone::asia::RAW_MACAO, &[
            "Asia/Macao",
            "asia/macao",
            "ASIA/MACAO",
            "aSIA/mACAO",
            "AsIa/mAcAo",
            "aSiA/MaCaO",
        ]),
        (time_zone::asia::MACAU, time_zone::asia::RAW_MACAU, &[
            "Asia/Macau",
            "asia/macau",
            "ASIA/MACAU",
            "aSIA/mACAU",
            "AsIa/mAcAu",
            "aSiA/MaCaU",
        ]),
        (time_zone::asia::MAGADAN, time_zone::asia::RAW_MAGADAN, &[
            "Asia/Magadan",
            "asia/magadan",
            "ASIA/MAGADAN",
            "aSIA/mAGADAN",
            "AsIa/mAgAdAn",
            "aSiA/MaGaDaN",
        ]),
        (time_zone::asia::MAKASSAR, time_zone::asia::RAW_MAKASSAR, &[
            "Asia/Makassar",
            "asia/makassar",
            "ASIA/MAKASSAR",
            "aSIA/mAKASSAR",
            "AsIa/mAkAsSaR",
            "aSiA/MaKaSsAr",
        ]),
        (
            time_zone::asia::UJUNG_PANDANG,
            time_zone::asia::RAW_UJUNG_PANDANG,
            &[
                "Asia/Ujung_Pandang",
                "asia/ujung_pandang",
                "ASIA/UJUNG_PANDANG",
                "aSIA/uJUNG_pANDANG",
                "AsIa/uJuNg_pAnDaNg",
                "aSiA/UjUnG_PaNdAnG",
            ],
        ),
        (time_zone::asia::MANILA, time_zone::asia::RAW_MANILA, &[
            "Asia/Manila",
            "asia/manila",
            "ASIA/MANILA",
            "aSIA/mANILA",
            "AsIa/mAnIlA",
            "aSiA/MaNiLa",
        ]),
        (time_zone::asia::MUSCAT, time_zone::asia::RAW_MUSCAT, &[
            "Asia/Muscat",
            "asia/muscat",
            "ASIA/MUSCAT",
            "aSIA/mUSCAT",
            "AsIa/mUsCaT",
            "aSiA/MuScAt",
        ]),
        (time_zone::asia::NICOSIA, time_zone::asia::RAW_NICOSIA, &[
            "Asia/Nicosia",
            "asia/nicosia",
            "ASIA/NICOSIA",
            "aSIA/nICOSIA",
            "AsIa/nIcOsIa",
            "aSiA/NiCoSiA",
        ]),
        (
            time_zone::europe::NICOSIA,
            time_zone::europe::RAW_NICOSIA,
            &[
                "Europe/Nicosia",
                "europe/nicosia",
                "EUROPE/NICOSIA",
                "eUROPE/nICOSIA",
                "EuRoPe/nIcOsIa",
                "eUrOpE/NiCoSiA",
            ],
        ),
        (
            time_zone::asia::NOVOKUZNETSK,
            time_zone::asia::RAW_NOVOKUZNETSK,
            &[
                "Asia/Novokuznetsk",
                "asia/novokuznetsk",
                "ASIA/NOVOKUZNETSK",
                "aSIA/nOVOKUZNETSK",
                "AsIa/nOvOkUzNeTsK",
                "aSiA/NoVoKuZnEtSk",
            ],
        ),
        (
            time_zone::asia::NOVOSIBIRSK,
            time_zone::asia::RAW_NOVOSIBIRSK,
            &[
                "Asia/Novosibirsk",
                "asia/novosibirsk",
                "ASIA/NOVOSIBIRSK",
                "aSIA/nOVOSIBIRSK",
                "AsIa/nOvOsIbIrSk",
                "aSiA/NoVoSiBiRsK",
            ],
        ),
        (time_zone::asia::OMSK, time_zone::asia::RAW_OMSK, &[
            "Asia/Omsk",
            "asia/omsk",
            "ASIA/OMSK",
            "aSIA/oMSK",
            "AsIa/oMsK",
            "aSiA/OmSk",
        ]),
        (time_zone::asia::ORAL, time_zone::asia::RAW_ORAL, &[
            "Asia/Oral",
            "asia/oral",
            "ASIA/ORAL",
            "aSIA/oRAL",
            "AsIa/oRaL",
            "aSiA/OrAl",
        ]),
        (
            time_zone::asia::PHNOM_PENH,
            time_zone::asia::RAW_PHNOM_PENH,
            &[
                "Asia/Phnom_Penh",
                "asia/phnom_penh",
                "ASIA/PHNOM_PENH",
                "aSIA/pHNOM_pENH",
                "AsIa/pHnOm_pEnH",
                "aSiA/PhNoM_PeNh",
            ],
        ),
        (
            time_zone::asia::PONTIANAK,
            time_zone::asia::RAW_PONTIANAK,
            &[
                "Asia/Pontianak",
                "asia/pontianak",
                "ASIA/PONTIANAK",
                "aSIA/pONTIANAK",
                "AsIa/pOnTiAnAk",
                "aSiA/PoNtIaNaK",
            ],
        ),
        (
            time_zone::asia::PYONGYANG,
            time_zone::asia::RAW_PYONGYANG,
            &[
                "Asia/Pyongyang",
                "asia/pyongyang",
                "ASIA/PYONGYANG",
                "aSIA/pYONGYANG",
                "AsIa/pYoNgYaNg",
                "aSiA/PyOnGyAnG",
            ],
        ),
        (time_zone::asia::QATAR, time_zone::asia::RAW_QATAR, &[
            "Asia/Qatar",
            "asia/qatar",
            "ASIA/QATAR",
            "aSIA/qATAR",
            "AsIa/qAtAr",
            "aSiA/QaTaR",
        ]),
        (time_zone::asia::QOSTANAY, time_zone::asia::RAW_QOSTANAY, &[
            "Asia/Qostanay",
            "asia/qostanay",
            "ASIA/QOSTANAY",
            "aSIA/qOSTANAY",
            "AsIa/qOsTaNaY",
            "aSiA/QoStAnAy",
        ]),
        (
            time_zone::asia::QYZYLORDA,
            time_zone::asia::RAW_QYZYLORDA,
            &[
                "Asia/Qyzylorda",
                "asia/qyzylorda",
                "ASIA/QYZYLORDA",
                "aSIA/qYZYLORDA",
                "AsIa/qYzYlOrDa",
                "aSiA/QyZyLoRdA",
            ],
        ),
        (time_zone::asia::RANGOON, time_zone::asia::RAW_RANGOON, &[
            "Asia/Rangoon",
            "asia/rangoon",
            "ASIA/RANGOON",
            "aSIA/rANGOON",
            "AsIa/rAnGoOn",
            "aSiA/RaNgOoN",
        ]),
        (time_zone::asia::YANGON, time_zone::asia::RAW_YANGON, &[
            "Asia/Yangon",
            "asia/yangon",
            "ASIA/YANGON",
            "aSIA/yANGON",
            "AsIa/yAnGoN",
            "aSiA/YaNgOn",
        ]),
        (time_zone::asia::RIYADH, time_zone::asia::RAW_RIYADH, &[
            "Asia/Riyadh",
            "asia/riyadh",
            "ASIA/RIYADH",
            "aSIA/rIYADH",
            "AsIa/rIyAdH",
            "aSiA/RiYaDh",
        ]),
        (time_zone::asia::SAKHALIN, time_zone::asia::RAW_SAKHALIN, &[
            "Asia/Sakhalin",
            "asia/sakhalin",
            "ASIA/SAKHALIN",
            "aSIA/sAKHALIN",
            "AsIa/sAkHaLiN",
            "aSiA/SaKhAlIn",
        ]),
        (
            time_zone::asia::SAMARKAND,
            time_zone::asia::RAW_SAMARKAND,
            &[
                "Asia/Samarkand",
                "asia/samarkand",
                "ASIA/SAMARKAND",
                "aSIA/sAMARKAND",
                "AsIa/sAmArKaNd",
                "aSiA/SaMaRkAnD",
            ],
        ),
        (
            time_zone::asia::SREDNEKOLYMSK,
            time_zone::asia::RAW_SREDNEKOLYMSK,
            &[
                "Asia/Srednekolymsk",
                "asia/srednekolymsk",
                "ASIA/SREDNEKOLYMSK",
                "aSIA/sREDNEKOLYMSK",
                "AsIa/sReDnEkOlYmSk",
                "aSiA/SrEdNeKoLyMsK",
            ],
        ),
        (time_zone::asia::TASHKENT, time_zone::asia::RAW_TASHKENT, &[
            "Asia/Tashkent",
            "asia/tashkent",
            "ASIA/TASHKENT",
            "aSIA/tASHKENT",
            "AsIa/tAsHkEnT",
            "aSiA/TaShKeNt",
        ]),
        (time_zone::asia::TBILISI, time_zone::asia::RAW_TBILISI, &[
            "Asia/Tbilisi",
            "asia/tbilisi",
            "ASIA/TBILISI",
            "aSIA/tBILISI",
            "AsIa/tBiLiSi",
            "aSiA/TbIlIsI",
        ]),
        (time_zone::asia::THIMBU, time_zone::asia::RAW_THIMBU, &[
            "Asia/Thimbu",
            "asia/thimbu",
            "ASIA/THIMBU",
            "aSIA/tHIMBU",
            "AsIa/tHiMbU",
            "aSiA/ThImBu",
        ]),
        (time_zone::asia::THIMPHU, time_zone::asia::RAW_THIMPHU, &[
            "Asia/Thimphu",
            "asia/thimphu",
            "ASIA/THIMPHU",
            "aSIA/tHIMPHU",
            "AsIa/tHiMpHu",
            "aSiA/ThImPhU",
        ]),
        (time_zone::asia::TOMSK, time_zone::asia::RAW_TOMSK, &[
            "Asia/Tomsk",
            "asia/tomsk",
            "ASIA/TOMSK",
            "aSIA/tOMSK",
            "AsIa/tOmSk",
            "aSiA/ToMsK",
        ]),
        (
            time_zone::asia::ULAANBAATAR,
            time_zone::asia::RAW_ULAANBAATAR,
            &[
                "Asia/Ulaanbaatar",
                "asia/ulaanbaatar",
                "ASIA/ULAANBAATAR",
                "aSIA/uLAANBAATAR",
                "AsIa/uLaAnBaAtAr",
                "aSiA/UlAaNbAaTaR",
            ],
        ),
        (
            time_zone::asia::ULAN_BATOR,
            time_zone::asia::RAW_ULAN_BATOR,
            &[
                "Asia/Ulan_Bator",
                "asia/ulan_bator",
                "ASIA/ULAN_BATOR",
                "aSIA/uLAN_bATOR",
                "AsIa/uLaN_BaToR",
                "aSiA/UlAn_bAtOr",
            ],
        ),
        (time_zone::asia::UST_NERA, time_zone::asia::RAW_UST_NERA, &[
            "Asia/Ust-Nera",
            "asia/ust-nera",
            "ASIA/UST-NERA",
            "aSIA/uST-nERA",
            "AsIa/uSt-nErA",
            "aSiA/UsT-NeRa",
        ]),
        (
            time_zone::asia::VIENTIANE,
            time_zone::asia::RAW_VIENTIANE,
            &[
                "Asia/Vientiane",
                "asia/vientiane",
                "ASIA/VIENTIANE",
                "aSIA/vIENTIANE",
                "AsIa/vIeNtIaNe",
                "aSiA/ViEnTiAnE",
            ],
        ),
        (
            time_zone::asia::VLADIVOSTOK,
            time_zone::asia::RAW_VLADIVOSTOK,
            &[
                "Asia/Vladivostok",
                "asia/vladivostok",
                "ASIA/VLADIVOSTOK",
                "aSIA/vLADIVOSTOK",
                "AsIa/vLaDiVoStOk",
                "aSiA/VlAdIvOsToK",
            ],
        ),
        (time_zone::asia::YAKUTSK, time_zone::asia::RAW_YAKUTSK, &[
            "Asia/Yakutsk",
            "asia/yakutsk",
            "ASIA/YAKUTSK",
            "aSIA/yAKUTSK",
            "AsIa/yAkUtSk",
            "aSiA/YaKuTsK",
        ]),
        (
            time_zone::asia::YEKATERINBURG,
            time_zone::asia::RAW_YEKATERINBURG,
            &[
                "Asia/Yekaterinburg",
                "asia/yekaterinburg",
                "ASIA/YEKATERINBURG",
                "aSIA/yEKATERINBURG",
                "AsIa/yEkAtErInBuRg",
                "aSiA/YeKaTeRiNbUrG",
            ],
        ),
        (time_zone::asia::YEREVAN, time_zone::asia::RAW_YEREVAN, &[
            "Asia/Yerevan",
            "asia/yerevan",
            "ASIA/YEREVAN",
            "aSIA/yEREVAN",
            "AsIa/yErEvAn",
            "aSiA/YeReVaN",
        ]),
        (
            time_zone::atlantic::AZORES,
            time_zone::atlantic::RAW_AZORES,
            &[
                "Atlantic/Azores",
                "atlantic/azores",
                "ATLANTIC/AZORES",
                "aTLANTIC/aZORES",
                "AtLaNtIc/aZoReS",
                "aTlAnTiC/AzOrEs",
            ],
        ),
        (
            time_zone::atlantic::BERMUDA,
            time_zone::atlantic::RAW_BERMUDA,
            &[
                "Atlantic/Bermuda",
                "atlantic/bermuda",
                "ATLANTIC/BERMUDA",
                "aTLANTIC/bERMUDA",
                "AtLaNtIc/bErMuDa",
                "aTlAnTiC/BeRmUdA",
            ],
        ),
        (
            time_zone::atlantic::CANARY,
            time_zone::atlantic::RAW_CANARY,
            &[
                "Atlantic/Canary",
                "atlantic/canary",
                "ATLANTIC/CANARY",
                "aTLANTIC/cANARY",
                "AtLaNtIc/cAnArY",
                "aTlAnTiC/CaNaRy",
            ],
        ),
        (
            time_zone::atlantic::CAPE_VERDE,
            time_zone::atlantic::RAW_CAPE_VERDE,
            &[
                "Atlantic/Cape_Verde",
                "atlantic/cape_verde",
                "ATLANTIC/CAPE_VERDE",
                "aTLANTIC/cAPE_vERDE",
                "AtLaNtIc/cApE_VeRdE",
                "aTlAnTiC/CaPe_vErDe",
            ],
        ),
        (
            time_zone::atlantic::FAEROE,
            time_zone::atlantic::RAW_FAEROE,
            &[
                "Atlantic/Faeroe",
                "atlantic/faeroe",
                "ATLANTIC/FAEROE",
                "aTLANTIC/fAEROE",
                "AtLaNtIc/fAeRoE",
                "aTlAnTiC/FaErOe",
            ],
        ),
        (
            time_zone::atlantic::FAROE,
            time_zone::atlantic::RAW_FAROE,
            &[
                "Atlantic/Faroe",
                "atlantic/faroe",
                "ATLANTIC/FAROE",
                "aTLANTIC/fAROE",
                "AtLaNtIc/fArOe",
                "aTlAnTiC/FaRoE",
            ],
        ),
        (
            time_zone::atlantic::MADEIRA,
            time_zone::atlantic::RAW_MADEIRA,
            &[
                "Atlantic/Madeira",
                "atlantic/madeira",
                "ATLANTIC/MADEIRA",
                "aTLANTIC/mADEIRA",
                "AtLaNtIc/mAdEiRa",
                "aTlAnTiC/MaDeIrA",
            ],
        ),
        (
            time_zone::atlantic::REYKJAVIK,
            time_zone::atlantic::RAW_REYKJAVIK,
            &[
                "Atlantic/Reykjavik",
                "atlantic/reykjavik",
                "ATLANTIC/REYKJAVIK",
                "aTLANTIC/rEYKJAVIK",
                "AtLaNtIc/rEyKjAvIk",
                "aTlAnTiC/ReYkJaViK",
            ],
        ),
        (
            time_zone::atlantic::SOUTH_GEORGIA,
            time_zone::atlantic::RAW_SOUTH_GEORGIA,
            &[
                "Atlantic/South_Georgia",
                "atlantic/south_georgia",
                "ATLANTIC/SOUTH_GEORGIA",
                "aTLANTIC/sOUTH_gEORGIA",
                "AtLaNtIc/sOuTh_gEoRgIa",
                "aTlAnTiC/SoUtH_GeOrGiA",
            ],
        ),
        (
            time_zone::atlantic::STANLEY,
            time_zone::atlantic::RAW_STANLEY,
            &[
                "Atlantic/Stanley",
                "atlantic/stanley",
                "ATLANTIC/STANLEY",
                "aTLANTIC/sTANLEY",
                "AtLaNtIc/sTaNlEy",
                "aTlAnTiC/StAnLeY",
            ],
        ),
        (
            time_zone::atlantic::ST_HELENA,
            time_zone::atlantic::RAW_ST_HELENA,
            &[
                "Atlantic/St_Helena",
                "atlantic/st_helena",
                "ATLANTIC/ST_HELENA",
                "aTLANTIC/sT_hELENA",
                "AtLaNtIc/sT_HeLeNa",
                "aTlAnTiC/St_hElEnA",
            ],
        ),
        (time_zone::australia::ACT, time_zone::australia::RAW_ACT, &[
            "Australia/ACT",
            "australia/act",
            "AUSTRALIA/ACT",
            "aUSTRALIA/act",
            "AuStRaLiA/AcT",
            "aUsTrAlIa/aCt",
        ]),
        (
            time_zone::australia::CANBERRA,
            time_zone::australia::RAW_CANBERRA,
            &[
                "Australia/Canberra",
                "australia/canberra",
                "AUSTRALIA/CANBERRA",
                "aUSTRALIA/cANBERRA",
                "AuStRaLiA/CaNbErRa",
                "aUsTrAlIa/cAnBeRrA",
            ],
        ),
        (time_zone::australia::NSW, time_zone::australia::RAW_NSW, &[
            "Australia/NSW",
            "australia/nsw",
            "AUSTRALIA/NSW",
            "aUSTRALIA/nsw",
            "AuStRaLiA/NsW",
            "aUsTrAlIa/nSw",
        ]),
        (
            time_zone::australia::SYDNEY,
            time_zone::australia::RAW_SYDNEY,
            &[
                "Australia/Sydney",
                "australia/sydney",
                "AUSTRALIA/SYDNEY",
                "aUSTRALIA/sYDNEY",
                "AuStRaLiA/SyDnEy",
                "aUsTrAlIa/sYdNeY",
            ],
        ),
        (
            time_zone::australia::ADELAIDE,
            time_zone::australia::RAW_ADELAIDE,
            &[
                "Australia/Adelaide",
                "australia/adelaide",
                "AUSTRALIA/ADELAIDE",
                "aUSTRALIA/aDELAIDE",
                "AuStRaLiA/AdElAiDe",
                "aUsTrAlIa/aDeLaIdE",
            ],
        ),
        (
            time_zone::australia::SOUTH,
            time_zone::australia::RAW_SOUTH,
            &[
                "Australia/South",
                "australia/south",
                "AUSTRALIA/SOUTH",
                "aUSTRALIA/sOUTH",
                "AuStRaLiA/SoUtH",
                "aUsTrAlIa/sOuTh",
            ],
        ),
        (
            time_zone::australia::BRISBANE,
            time_zone::australia::RAW_BRISBANE,
            &[
                "Australia/Brisbane",
                "australia/brisbane",
                "AUSTRALIA/BRISBANE",
                "aUSTRALIA/bRISBANE",
                "AuStRaLiA/BrIsBaNe",
                "aUsTrAlIa/bRiSbAnE",
            ],
        ),
        (
            time_zone::australia::QUEENSLAND,
            time_zone::australia::RAW_QUEENSLAND,
            &[
                "Australia/Queensland",
                "australia/queensland",
                "AUSTRALIA/QUEENSLAND",
                "aUSTRALIA/qUEENSLAND",
                "AuStRaLiA/QuEeNsLaNd",
                "aUsTrAlIa/qUeEnSlAnD",
            ],
        ),
        (
            time_zone::australia::BROKEN_HILL,
            time_zone::australia::RAW_BROKEN_HILL,
            &[
                "Australia/Broken_Hill",
                "australia/broken_hill",
                "AUSTRALIA/BROKEN_HILL",
                "aUSTRALIA/bROKEN_hILL",
                "AuStRaLiA/BrOkEn_hIlL",
                "aUsTrAlIa/bRoKeN_HiLl",
            ],
        ),
        (
            time_zone::australia::YANCOWINNA,
            time_zone::australia::RAW_YANCOWINNA,
            &[
                "Australia/Yancowinna",
                "australia/yancowinna",
                "AUSTRALIA/YANCOWINNA",
                "aUSTRALIA/yANCOWINNA",
                "AuStRaLiA/YaNcOwInNa",
                "aUsTrAlIa/yAnCoWiNnA",
            ],
        ),
        (
            time_zone::australia::CURRIE,
            time_zone::australia::RAW_CURRIE,
            &[
                "Australia/Currie",
                "australia/currie",
                "AUSTRALIA/CURRIE",
                "aUSTRALIA/cURRIE",
                "AuStRaLiA/CuRrIe",
                "aUsTrAlIa/cUrRiE",
            ],
        ),
        (
            time_zone::australia::HOBART,
            time_zone::australia::RAW_HOBART,
            &[
                "Australia/Hobart",
                "australia/hobart",
                "AUSTRALIA/HOBART",
                "aUSTRALIA/hOBART",
                "AuStRaLiA/HoBaRt",
                "aUsTrAlIa/hObArT",
            ],
        ),
        (
            time_zone::australia::TASMANIA,
            time_zone::australia::RAW_TASMANIA,
            &[
                "Australia/Tasmania",
                "australia/tasmania",
                "AUSTRALIA/TASMANIA",
                "aUSTRALIA/tASMANIA",
                "AuStRaLiA/TaSmAnIa",
                "aUsTrAlIa/tAsMaNiA",
            ],
        ),
        (
            time_zone::australia::DARWIN,
            time_zone::australia::RAW_DARWIN,
            &[
                "Australia/Darwin",
                "australia/darwin",
                "AUSTRALIA/DARWIN",
                "aUSTRALIA/dARWIN",
                "AuStRaLiA/DaRwIn",
                "aUsTrAlIa/dArWiN",
            ],
        ),
        (
            time_zone::australia::NORTH,
            time_zone::australia::RAW_NORTH,
            &[
                "Australia/North",
                "australia/north",
                "AUSTRALIA/NORTH",
                "aUSTRALIA/nORTH",
                "AuStRaLiA/NoRtH",
                "aUsTrAlIa/nOrTh",
            ],
        ),
        (
            time_zone::australia::EUCLA,
            time_zone::australia::RAW_EUCLA,
            &[
                "Australia/Eucla",
                "australia/eucla",
                "AUSTRALIA/EUCLA",
                "aUSTRALIA/eUCLA",
                "AuStRaLiA/EuClA",
                "aUsTrAlIa/eUcLa",
            ],
        ),
        (time_zone::australia::LHI, time_zone::australia::RAW_LHI, &[
            "Australia/LHI",
            "australia/lhi",
            "AUSTRALIA/LHI",
            "aUSTRALIA/lhi",
            "AuStRaLiA/LhI",
            "aUsTrAlIa/lHi",
        ]),
        (
            time_zone::australia::LORD_HOWE,
            time_zone::australia::RAW_LORD_HOWE,
            &[
                "Australia/Lord_Howe",
                "australia/lord_howe",
                "AUSTRALIA/LORD_HOWE",
                "aUSTRALIA/lORD_hOWE",
                "AuStRaLiA/LoRd_hOwE",
                "aUsTrAlIa/lOrD_HoWe",
            ],
        ),
        (
            time_zone::australia::LINDEMAN,
            time_zone::australia::RAW_LINDEMAN,
            &[
                "Australia/Lindeman",
                "australia/lindeman",
                "AUSTRALIA/LINDEMAN",
                "aUSTRALIA/lINDEMAN",
                "AuStRaLiA/LiNdEmAn",
                "aUsTrAlIa/lInDeMaN",
            ],
        ),
        (
            time_zone::australia::MELBOURNE,
            time_zone::australia::RAW_MELBOURNE,
            &[
                "Australia/Melbourne",
                "australia/melbourne",
                "AUSTRALIA/MELBOURNE",
                "aUSTRALIA/mELBOURNE",
                "AuStRaLiA/MeLbOuRnE",
                "aUsTrAlIa/mElBoUrNe",
            ],
        ),
        (
            time_zone::australia::VICTORIA,
            time_zone::australia::RAW_VICTORIA,
            &[
                "Australia/Victoria",
                "australia/victoria",
                "AUSTRALIA/VICTORIA",
                "aUSTRALIA/vICTORIA",
                "AuStRaLiA/ViCtOrIa",
                "aUsTrAlIa/vIcToRiA",
            ],
        ),
        (
            time_zone::australia::PERTH,
            time_zone::australia::RAW_PERTH,
            &[
                "Australia/Perth",
                "australia/perth",
                "AUSTRALIA/PERTH",
                "aUSTRALIA/pERTH",
                "AuStRaLiA/PeRtH",
                "aUsTrAlIa/pErTh",
            ],
        ),
        (
            time_zone::australia::WEST,
            time_zone::australia::RAW_WEST,
            &[
                "Australia/West",
                "australia/west",
                "AUSTRALIA/WEST",
                "aUSTRALIA/wEST",
                "AuStRaLiA/WeSt",
                "aUsTrAlIa/wEsT",
            ],
        ),
        (time_zone::CET, time_zone::RAW_CET, &[
            "CET", "cet", "CET", "cet", "CeT", "cEt",
        ]),
        (
            time_zone::chile::EASTER_ISLAND,
            time_zone::chile::RAW_EASTER_ISLAND,
            &[
                "Chile/EasterIsland",
                "chile/easterisland",
                "CHILE/EASTERISLAND",
                "cHILE/eASTERiSLAND",
                "ChIlE/EaStErIsLaNd",
                "cHiLe/eAsTeRiSlAnD",
            ],
        ),
        (
            time_zone::pacific::EASTER,
            time_zone::pacific::RAW_EASTER,
            &[
                "Pacific/Easter",
                "pacific/easter",
                "PACIFIC/EASTER",
                "pACIFIC/eASTER",
                "PaCiFiC/EaStEr",
                "pAcIfIc/eAsTeR",
            ],
        ),
        (time_zone::CST_6_CDT, time_zone::RAW_CST_6_CDT, &[
            "CST6CDT", "cst6cdt", "CST6CDT", "cst6cdt", "CsT6CdT", "cSt6cDt",
        ]),
        (time_zone::CUBA, time_zone::RAW_CUBA, &[
            "Cuba", "cuba", "CUBA", "cUBA", "CuBa", "cUbA",
        ]),
        (
            time_zone::america::HAVANA,
            time_zone::america::RAW_HAVANA,
            &[
                "America/Havana",
                "america/havana",
                "AMERICA/HAVANA",
                "aMERICA/hAVANA",
                "AmErIcA/HaVaNa",
                "aMeRiCa/hAvAnA",
            ],
        ),
        (time_zone::EET, time_zone::RAW_EET, &[
            "EET", "eet", "EET", "eet", "EeT", "eEt",
        ]),
        (time_zone::EGYPT, time_zone::RAW_EGYPT, &[
            "Egypt", "egypt", "EGYPT", "eGYPT", "EgYpT", "eGyPt",
        ]),
        (time_zone::africa::CAIRO, time_zone::africa::RAW_CAIRO, &[
            "Africa/Cairo",
            "africa/cairo",
            "AFRICA/CAIRO",
            "aFRICA/cAIRO",
            "AfRiCa/cAiRo",
            "aFrIcA/CaIrO",
        ]),
        (time_zone::EIRE, time_zone::RAW_EIRE, &[
            "Eire", "eire", "EIRE", "eIRE", "EiRe", "eIrE",
        ]),
        (time_zone::europe::DUBLIN, time_zone::europe::RAW_DUBLIN, &[
            "Europe/Dublin",
            "europe/dublin",
            "EUROPE/DUBLIN",
            "eUROPE/dUBLIN",
            "EuRoPe/dUbLiN",
            "eUrOpE/DuBlIn",
        ]),
        (time_zone::EST, time_zone::RAW_EST, &[
            "EST", "est", "EST", "est", "EsT", "eSt",
        ]),
        (time_zone::EST_5_EDT, time_zone::RAW_EST_5_EDT, &[
            "EST5EDT", "est5edt", "EST5EDT", "est5edt", "EsT5EdT", "eSt5eDt",
        ]),
        (
            time_zone::etc::GMT_MINUS_1,
            time_zone::etc::RAW_GMT_MINUS_1,
            &[
                "Etc/GMT-1",
                "etc/gmt-1",
                "ETC/GMT-1",
                "eTC/gmt-1",
                "EtC/GmT-1",
                "eTc/gMt-1",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_10,
            time_zone::etc::RAW_GMT_MINUS_10,
            &[
                "Etc/GMT-10",
                "etc/gmt-10",
                "ETC/GMT-10",
                "eTC/gmt-10",
                "EtC/GmT-10",
                "eTc/gMt-10",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_11,
            time_zone::etc::RAW_GMT_MINUS_11,
            &[
                "Etc/GMT-11",
                "etc/gmt-11",
                "ETC/GMT-11",
                "eTC/gmt-11",
                "EtC/GmT-11",
                "eTc/gMt-11",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_12,
            time_zone::etc::RAW_GMT_MINUS_12,
            &[
                "Etc/GMT-12",
                "etc/gmt-12",
                "ETC/GMT-12",
                "eTC/gmt-12",
                "EtC/GmT-12",
                "eTc/gMt-12",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_13,
            time_zone::etc::RAW_GMT_MINUS_13,
            &[
                "Etc/GMT-13",
                "etc/gmt-13",
                "ETC/GMT-13",
                "eTC/gmt-13",
                "EtC/GmT-13",
                "eTc/gMt-13",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_14,
            time_zone::etc::RAW_GMT_MINUS_14,
            &[
                "Etc/GMT-14",
                "etc/gmt-14",
                "ETC/GMT-14",
                "eTC/gmt-14",
                "EtC/GmT-14",
                "eTc/gMt-14",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_2,
            time_zone::etc::RAW_GMT_MINUS_2,
            &[
                "Etc/GMT-2",
                "etc/gmt-2",
                "ETC/GMT-2",
                "eTC/gmt-2",
                "EtC/GmT-2",
                "eTc/gMt-2",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_3,
            time_zone::etc::RAW_GMT_MINUS_3,
            &[
                "Etc/GMT-3",
                "etc/gmt-3",
                "ETC/GMT-3",
                "eTC/gmt-3",
                "EtC/GmT-3",
                "eTc/gMt-3",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_4,
            time_zone::etc::RAW_GMT_MINUS_4,
            &[
                "Etc/GMT-4",
                "etc/gmt-4",
                "ETC/GMT-4",
                "eTC/gmt-4",
                "EtC/GmT-4",
                "eTc/gMt-4",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_5,
            time_zone::etc::RAW_GMT_MINUS_5,
            &[
                "Etc/GMT-5",
                "etc/gmt-5",
                "ETC/GMT-5",
                "eTC/gmt-5",
                "EtC/GmT-5",
                "eTc/gMt-5",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_6,
            time_zone::etc::RAW_GMT_MINUS_6,
            &[
                "Etc/GMT-6",
                "etc/gmt-6",
                "ETC/GMT-6",
                "eTC/gmt-6",
                "EtC/GmT-6",
                "eTc/gMt-6",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_7,
            time_zone::etc::RAW_GMT_MINUS_7,
            &[
                "Etc/GMT-7",
                "etc/gmt-7",
                "ETC/GMT-7",
                "eTC/gmt-7",
                "EtC/GmT-7",
                "eTc/gMt-7",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_8,
            time_zone::etc::RAW_GMT_MINUS_8,
            &[
                "Etc/GMT-8",
                "etc/gmt-8",
                "ETC/GMT-8",
                "eTC/gmt-8",
                "EtC/GmT-8",
                "eTc/gMt-8",
            ],
        ),
        (
            time_zone::etc::GMT_MINUS_9,
            time_zone::etc::RAW_GMT_MINUS_9,
            &[
                "Etc/GMT-9",
                "etc/gmt-9",
                "ETC/GMT-9",
                "eTC/gmt-9",
                "EtC/GmT-9",
                "eTc/gMt-9",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_1,
            time_zone::etc::RAW_GMT_PLUS_1,
            &[
                "Etc/GMT+1",
                "etc/gmt+1",
                "ETC/GMT+1",
                "eTC/gmt+1",
                "EtC/GmT+1",
                "eTc/gMt+1",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_10,
            time_zone::etc::RAW_GMT_PLUS_10,
            &[
                "Etc/GMT+10",
                "etc/gmt+10",
                "ETC/GMT+10",
                "eTC/gmt+10",
                "EtC/GmT+10",
                "eTc/gMt+10",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_11,
            time_zone::etc::RAW_GMT_PLUS_11,
            &[
                "Etc/GMT+11",
                "etc/gmt+11",
                "ETC/GMT+11",
                "eTC/gmt+11",
                "EtC/GmT+11",
                "eTc/gMt+11",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_12,
            time_zone::etc::RAW_GMT_PLUS_12,
            &[
                "Etc/GMT+12",
                "etc/gmt+12",
                "ETC/GMT+12",
                "eTC/gmt+12",
                "EtC/GmT+12",
                "eTc/gMt+12",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_2,
            time_zone::etc::RAW_GMT_PLUS_2,
            &[
                "Etc/GMT+2",
                "etc/gmt+2",
                "ETC/GMT+2",
                "eTC/gmt+2",
                "EtC/GmT+2",
                "eTc/gMt+2",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_3,
            time_zone::etc::RAW_GMT_PLUS_3,
            &[
                "Etc/GMT+3",
                "etc/gmt+3",
                "ETC/GMT+3",
                "eTC/gmt+3",
                "EtC/GmT+3",
                "eTc/gMt+3",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_4,
            time_zone::etc::RAW_GMT_PLUS_4,
            &[
                "Etc/GMT+4",
                "etc/gmt+4",
                "ETC/GMT+4",
                "eTC/gmt+4",
                "EtC/GmT+4",
                "eTc/gMt+4",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_5,
            time_zone::etc::RAW_GMT_PLUS_5,
            &[
                "Etc/GMT+5",
                "etc/gmt+5",
                "ETC/GMT+5",
                "eTC/gmt+5",
                "EtC/GmT+5",
                "eTc/gMt+5",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_6,
            time_zone::etc::RAW_GMT_PLUS_6,
            &[
                "Etc/GMT+6",
                "etc/gmt+6",
                "ETC/GMT+6",
                "eTC/gmt+6",
                "EtC/GmT+6",
                "eTc/gMt+6",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_7,
            time_zone::etc::RAW_GMT_PLUS_7,
            &[
                "Etc/GMT+7",
                "etc/gmt+7",
                "ETC/GMT+7",
                "eTC/gmt+7",
                "EtC/GmT+7",
                "eTc/gMt+7",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_8,
            time_zone::etc::RAW_GMT_PLUS_8,
            &[
                "Etc/GMT+8",
                "etc/gmt+8",
                "ETC/GMT+8",
                "eTC/gmt+8",
                "EtC/GmT+8",
                "eTc/gMt+8",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_9,
            time_zone::etc::RAW_GMT_PLUS_9,
            &[
                "Etc/GMT+9",
                "etc/gmt+9",
                "ETC/GMT+9",
                "eTC/gmt+9",
                "EtC/GmT+9",
                "eTc/gMt+9",
            ],
        ),
        (
            time_zone::europe::AMSTERDAM,
            time_zone::europe::RAW_AMSTERDAM,
            &[
                "Europe/Amsterdam",
                "europe/amsterdam",
                "EUROPE/AMSTERDAM",
                "eUROPE/aMSTERDAM",
                "EuRoPe/aMsTeRdAm",
                "eUrOpE/AmStErDaM",
            ],
        ),
        (
            time_zone::europe::ANDORRA,
            time_zone::europe::RAW_ANDORRA,
            &[
                "Europe/Andorra",
                "europe/andorra",
                "EUROPE/ANDORRA",
                "eUROPE/aNDORRA",
                "EuRoPe/aNdOrRa",
                "eUrOpE/AnDoRrA",
            ],
        ),
        (
            time_zone::europe::ASTRAKHAN,
            time_zone::europe::RAW_ASTRAKHAN,
            &[
                "Europe/Astrakhan",
                "europe/astrakhan",
                "EUROPE/ASTRAKHAN",
                "eUROPE/aSTRAKHAN",
                "EuRoPe/aStRaKhAn",
                "eUrOpE/AsTrAkHaN",
            ],
        ),
        (time_zone::europe::ATHENS, time_zone::europe::RAW_ATHENS, &[
            "Europe/Athens",
            "europe/athens",
            "EUROPE/ATHENS",
            "eUROPE/aTHENS",
            "EuRoPe/aThEnS",
            "eUrOpE/AtHeNs",
        ]),
        (
            time_zone::europe::BELGRADE,
            time_zone::europe::RAW_BELGRADE,
            &[
                "Europe/Belgrade",
                "europe/belgrade",
                "EUROPE/BELGRADE",
                "eUROPE/bELGRADE",
                "EuRoPe/bElGrAdE",
                "eUrOpE/BeLgRaDe",
            ],
        ),
        (
            time_zone::europe::PODGORICA,
            time_zone::europe::RAW_PODGORICA,
            &[
                "Europe/Podgorica",
                "europe/podgorica",
                "EUROPE/PODGORICA",
                "eUROPE/pODGORICA",
                "EuRoPe/pOdGoRiCa",
                "eUrOpE/PoDgOrIcA",
            ],
        ),
        (
            time_zone::europe::BRATISLAVA,
            time_zone::europe::RAW_BRATISLAVA,
            &[
                "Europe/Bratislava",
                "europe/bratislava",
                "EUROPE/BRATISLAVA",
                "eUROPE/bRATISLAVA",
                "EuRoPe/bRaTiSlAvA",
                "eUrOpE/BrAtIsLaVa",
            ],
        ),
        (time_zone::europe::PRAGUE, time_zone::europe::RAW_PRAGUE, &[
            "Europe/Prague",
            "europe/prague",
            "EUROPE/PRAGUE",
            "eUROPE/pRAGUE",
            "EuRoPe/pRaGuE",
            "eUrOpE/PrAgUe",
        ]),
        (
            time_zone::europe::BRUSSELS,
            time_zone::europe::RAW_BRUSSELS,
            &[
                "Europe/Brussels",
                "europe/brussels",
                "EUROPE/BRUSSELS",
                "eUROPE/bRUSSELS",
                "EuRoPe/bRuSsElS",
                "eUrOpE/BrUsSeLs",
            ],
        ),
        (
            time_zone::europe::BUCHAREST,
            time_zone::europe::RAW_BUCHAREST,
            &[
                "Europe/Bucharest",
                "europe/bucharest",
                "EUROPE/BUCHAREST",
                "eUROPE/bUCHAREST",
                "EuRoPe/bUcHaReSt",
                "eUrOpE/BuChArEsT",
            ],
        ),
        (
            time_zone::europe::BUDAPEST,
            time_zone::europe::RAW_BUDAPEST,
            &[
                "Europe/Budapest",
                "europe/budapest",
                "EUROPE/BUDAPEST",
                "eUROPE/bUDAPEST",
                "EuRoPe/bUdApEsT",
                "eUrOpE/BuDaPeSt",
            ],
        ),
        (
            time_zone::europe::BUSINGEN,
            time_zone::europe::RAW_BUSINGEN,
            &[
                "Europe/Busingen",
                "europe/busingen",
                "EUROPE/BUSINGEN",
                "eUROPE/bUSINGEN",
                "EuRoPe/bUsInGeN",
                "eUrOpE/BuSiNgEn",
            ],
        ),
        (time_zone::europe::ZURICH, time_zone::europe::RAW_ZURICH, &[
            "Europe/Zurich",
            "europe/zurich",
            "EUROPE/ZURICH",
            "eUROPE/zURICH",
            "EuRoPe/zUrIcH",
            "eUrOpE/ZuRiCh",
        ]),
        (
            time_zone::europe::CHISINAU,
            time_zone::europe::RAW_CHISINAU,
            &[
                "Europe/Chisinau",
                "europe/chisinau",
                "EUROPE/CHISINAU",
                "eUROPE/cHISINAU",
                "EuRoPe/cHiSiNaU",
                "eUrOpE/ChIsInAu",
            ],
        ),
        (
            time_zone::europe::TIRASPOL,
            time_zone::europe::RAW_TIRASPOL,
            &[
                "Europe/Tiraspol",
                "europe/tiraspol",
                "EUROPE/TIRASPOL",
                "eUROPE/tIRASPOL",
                "EuRoPe/tIrAsPoL",
                "eUrOpE/TiRaSpOl",
            ],
        ),
        (
            time_zone::europe::COPENHAGEN,
            time_zone::europe::RAW_COPENHAGEN,
            &[
                "Europe/Copenhagen",
                "europe/copenhagen",
                "EUROPE/COPENHAGEN",
                "eUROPE/cOPENHAGEN",
                "EuRoPe/cOpEnHaGeN",
                "eUrOpE/CoPeNhAgEn",
            ],
        ),
        (
            time_zone::europe::GIBRALTAR,
            time_zone::europe::RAW_GIBRALTAR,
            &[
                "Europe/Gibraltar",
                "europe/gibraltar",
                "EUROPE/GIBRALTAR",
                "eUROPE/gIBRALTAR",
                "EuRoPe/gIbRaLtAr",
                "eUrOpE/GiBrAlTaR",
            ],
        ),
        (
            time_zone::europe::GUERNSEY,
            time_zone::europe::RAW_GUERNSEY,
            &[
                "Europe/Guernsey",
                "europe/guernsey",
                "EUROPE/GUERNSEY",
                "eUROPE/gUERNSEY",
                "EuRoPe/gUeRnSeY",
                "eUrOpE/GuErNsEy",
            ],
        ),
        (
            time_zone::europe::HELSINKI,
            time_zone::europe::RAW_HELSINKI,
            &[
                "Europe/Helsinki",
                "europe/helsinki",
                "EUROPE/HELSINKI",
                "eUROPE/hELSINKI",
                "EuRoPe/hElSiNkI",
                "eUrOpE/HeLsInKi",
            ],
        ),
        (
            time_zone::europe::MARIEHAMN,
            time_zone::europe::RAW_MARIEHAMN,
            &[
                "Europe/Mariehamn",
                "europe/mariehamn",
                "EUROPE/MARIEHAMN",
                "eUROPE/mARIEHAMN",
                "EuRoPe/mArIeHaMn",
                "eUrOpE/MaRiEhAmN",
            ],
        ),
        (
            time_zone::europe::ISLE_OF_MAN,
            time_zone::europe::RAW_ISLE_OF_MAN,
            &[
                "Europe/Isle_of_Man",
                "europe/isle_of_man",
                "EUROPE/ISLE_OF_MAN",
                "eUROPE/iSLE_OF_mAN",
                "EuRoPe/iSlE_Of_mAn",
                "eUrOpE/IsLe_oF_MaN",
            ],
        ),
        (time_zone::europe::JERSEY, time_zone::europe::RAW_JERSEY, &[
            "Europe/Jersey",
            "europe/jersey",
            "EUROPE/JERSEY",
            "eUROPE/jERSEY",
            "EuRoPe/jErSeY",
            "eUrOpE/JeRsEy",
        ]),
        (
            time_zone::europe::KALININGRAD,
            time_zone::europe::RAW_KALININGRAD,
            &[
                "Europe/Kaliningrad",
                "europe/kaliningrad",
                "EUROPE/KALININGRAD",
                "eUROPE/kALININGRAD",
                "EuRoPe/kAlInInGrAd",
                "eUrOpE/KaLiNiNgRaD",
            ],
        ),
        (time_zone::europe::KIEV, time_zone::europe::RAW_KIEV, &[
            "Europe/Kiev",
            "europe/kiev",
            "EUROPE/KIEV",
            "eUROPE/kIEV",
            "EuRoPe/kIeV",
            "eUrOpE/KiEv",
        ]),
        (time_zone::europe::KYIV, time_zone::europe::RAW_KYIV, &[
            "Europe/Kyiv",
            "europe/kyiv",
            "EUROPE/KYIV",
            "eUROPE/kYIV",
            "EuRoPe/kYiV",
            "eUrOpE/KyIv",
        ]),
        (
            time_zone::europe::UZHGOROD,
            time_zone::europe::RAW_UZHGOROD,
            &[
                "Europe/Uzhgorod",
                "europe/uzhgorod",
                "EUROPE/UZHGOROD",
                "eUROPE/uZHGOROD",
                "EuRoPe/uZhGoRoD",
                "eUrOpE/UzHgOrOd",
            ],
        ),
        (
            time_zone::europe::ZAPOROZHYE,
            time_zone::europe::RAW_ZAPOROZHYE,
            &[
                "Europe/Zaporozhye",
                "europe/zaporozhye",
                "EUROPE/ZAPOROZHYE",
                "eUROPE/zAPOROZHYE",
                "EuRoPe/zApOrOzHyE",
                "eUrOpE/ZaPoRoZhYe",
            ],
        ),
        (time_zone::europe::KIROV, time_zone::europe::RAW_KIROV, &[
            "Europe/Kirov",
            "europe/kirov",
            "EUROPE/KIROV",
            "eUROPE/kIROV",
            "EuRoPe/kIrOv",
            "eUrOpE/KiRoV",
        ]),
        (
            time_zone::europe::LJUBLJANA,
            time_zone::europe::RAW_LJUBLJANA,
            &[
                "Europe/Ljubljana",
                "europe/ljubljana",
                "EUROPE/LJUBLJANA",
                "eUROPE/lJUBLJANA",
                "EuRoPe/lJuBlJaNa",
                "eUrOpE/LjUbLjAnA",
            ],
        ),
        (
            time_zone::europe::LUXEMBOURG,
            time_zone::europe::RAW_LUXEMBOURG,
            &[
                "Europe/Luxembourg",
                "europe/luxembourg",
                "EUROPE/LUXEMBOURG",
                "eUROPE/lUXEMBOURG",
                "EuRoPe/lUxEmBoUrG",
                "eUrOpE/LuXeMbOuRg",
            ],
        ),
        (time_zone::europe::MADRID, time_zone::europe::RAW_MADRID, &[
            "Europe/Madrid",
            "europe/madrid",
            "EUROPE/MADRID",
            "eUROPE/mADRID",
            "EuRoPe/mAdRiD",
            "eUrOpE/MaDrId",
        ]),
        (time_zone::europe::MALTA, time_zone::europe::RAW_MALTA, &[
            "Europe/Malta",
            "europe/malta",
            "EUROPE/MALTA",
            "eUROPE/mALTA",
            "EuRoPe/mAlTa",
            "eUrOpE/MaLtA",
        ]),
        (time_zone::europe::MINSK, time_zone::europe::RAW_MINSK, &[
            "Europe/Minsk",
            "europe/minsk",
            "EUROPE/MINSK",
            "eUROPE/mINSK",
            "EuRoPe/mInSk",
            "eUrOpE/MiNsK",
        ]),
        (time_zone::europe::MONACO, time_zone::europe::RAW_MONACO, &[
            "Europe/Monaco",
            "europe/monaco",
            "EUROPE/MONACO",
            "eUROPE/mONACO",
            "EuRoPe/mOnAcO",
            "eUrOpE/MoNaCo",
        ]),
        (time_zone::europe::OSLO, time_zone::europe::RAW_OSLO, &[
            "Europe/Oslo",
            "europe/oslo",
            "EUROPE/OSLO",
            "eUROPE/oSLO",
            "EuRoPe/oSlO",
            "eUrOpE/OsLo",
        ]),
        (time_zone::europe::PARIS, time_zone::europe::RAW_PARIS, &[
            "Europe/Paris",
            "europe/paris",
            "EUROPE/PARIS",
            "eUROPE/pARIS",
            "EuRoPe/pArIs",
            "eUrOpE/PaRiS",
        ]),
        (time_zone::europe::RIGA, time_zone::europe::RAW_RIGA, &[
            "Europe/Riga",
            "europe/riga",
            "EUROPE/RIGA",
            "eUROPE/rIGA",
            "EuRoPe/rIgA",
            "eUrOpE/RiGa",
        ]),
        (time_zone::europe::ROME, time_zone::europe::RAW_ROME, &[
            "Europe/Rome",
            "europe/rome",
            "EUROPE/ROME",
            "eUROPE/rOME",
            "EuRoPe/rOmE",
            "eUrOpE/RoMe",
        ]),
        (
            time_zone::europe::SAN_MARINO,
            time_zone::europe::RAW_SAN_MARINO,
            &[
                "Europe/San_Marino",
                "europe/san_marino",
                "EUROPE/SAN_MARINO",
                "eUROPE/sAN_mARINO",
                "EuRoPe/sAn_mArInO",
                "eUrOpE/SaN_MaRiNo",
            ],
        ),
        (
            time_zone::europe::VATICAN,
            time_zone::europe::RAW_VATICAN,
            &[
                "Europe/Vatican",
                "europe/vatican",
                "EUROPE/VATICAN",
                "eUROPE/vATICAN",
                "EuRoPe/vAtIcAn",
                "eUrOpE/VaTiCaN",
            ],
        ),
        (time_zone::europe::SAMARA, time_zone::europe::RAW_SAMARA, &[
            "Europe/Samara",
            "europe/samara",
            "EUROPE/SAMARA",
            "eUROPE/sAMARA",
            "EuRoPe/sAmArA",
            "eUrOpE/SaMaRa",
        ]),
        (
            time_zone::europe::SARAJEVO,
            time_zone::europe::RAW_SARAJEVO,
            &[
                "Europe/Sarajevo",
                "europe/sarajevo",
                "EUROPE/SARAJEVO",
                "eUROPE/sARAJEVO",
                "EuRoPe/sArAjEvO",
                "eUrOpE/SaRaJeVo",
            ],
        ),
        (
            time_zone::europe::SARATOV,
            time_zone::europe::RAW_SARATOV,
            &[
                "Europe/Saratov",
                "europe/saratov",
                "EUROPE/SARATOV",
                "eUROPE/sARATOV",
                "EuRoPe/sArAtOv",
                "eUrOpE/SaRaToV",
            ],
        ),
        (
            time_zone::europe::SIMFEROPOL,
            time_zone::europe::RAW_SIMFEROPOL,
            &[
                "Europe/Simferopol",
                "europe/simferopol",
                "EUROPE/SIMFEROPOL",
                "eUROPE/sIMFEROPOL",
                "EuRoPe/sImFeRoPoL",
                "eUrOpE/SiMfErOpOl",
            ],
        ),
        (time_zone::europe::SKOPJE, time_zone::europe::RAW_SKOPJE, &[
            "Europe/Skopje",
            "europe/skopje",
            "EUROPE/SKOPJE",
            "eUROPE/sKOPJE",
            "EuRoPe/sKoPjE",
            "eUrOpE/SkOpJe",
        ]),
        (time_zone::europe::SOFIA, time_zone::europe::RAW_SOFIA, &[
            "Europe/Sofia",
            "europe/sofia",
            "EUROPE/SOFIA",
            "eUROPE/sOFIA",
            "EuRoPe/sOfIa",
            "eUrOpE/SoFiA",
        ]),
        (
            time_zone::europe::STOCKHOLM,
            time_zone::europe::RAW_STOCKHOLM,
            &[
                "Europe/Stockholm",
                "europe/stockholm",
                "EUROPE/STOCKHOLM",
                "eUROPE/sTOCKHOLM",
                "EuRoPe/sToCkHoLm",
                "eUrOpE/StOcKhOlM",
            ],
        ),
        (
            time_zone::europe::TALLINN,
            time_zone::europe::RAW_TALLINN,
            &[
                "Europe/Tallinn",
                "europe/tallinn",
                "EUROPE/TALLINN",
                "eUROPE/tALLINN",
                "EuRoPe/tAlLiNn",
                "eUrOpE/TaLlInN",
            ],
        ),
        (time_zone::europe::TIRANE, time_zone::europe::RAW_TIRANE, &[
            "Europe/Tirane",
            "europe/tirane",
            "EUROPE/TIRANE",
            "eUROPE/tIRANE",
            "EuRoPe/tIrAnE",
            "eUrOpE/TiRaNe",
        ]),
        (
            time_zone::europe::ULYANOVSK,
            time_zone::europe::RAW_ULYANOVSK,
            &[
                "Europe/Ulyanovsk",
                "europe/ulyanovsk",
                "EUROPE/ULYANOVSK",
                "eUROPE/uLYANOVSK",
                "EuRoPe/uLyAnOvSk",
                "eUrOpE/UlYaNoVsK",
            ],
        ),
        (time_zone::europe::VADUZ, time_zone::europe::RAW_VADUZ, &[
            "Europe/Vaduz",
            "europe/vaduz",
            "EUROPE/VADUZ",
            "eUROPE/vADUZ",
            "EuRoPe/vAdUz",
            "eUrOpE/VaDuZ",
        ]),
        (time_zone::europe::VIENNA, time_zone::europe::RAW_VIENNA, &[
            "Europe/Vienna",
            "europe/vienna",
            "EUROPE/VIENNA",
            "eUROPE/vIENNA",
            "EuRoPe/vIeNnA",
            "eUrOpE/ViEnNa",
        ]),
        (
            time_zone::europe::VILNIUS,
            time_zone::europe::RAW_VILNIUS,
            &[
                "Europe/Vilnius",
                "europe/vilnius",
                "EUROPE/VILNIUS",
                "eUROPE/vILNIUS",
                "EuRoPe/vIlNiUs",
                "eUrOpE/ViLnIuS",
            ],
        ),
        (
            time_zone::europe::VOLGOGRAD,
            time_zone::europe::RAW_VOLGOGRAD,
            &[
                "Europe/Volgograd",
                "europe/volgograd",
                "EUROPE/VOLGOGRAD",
                "eUROPE/vOLGOGRAD",
                "EuRoPe/vOlGoGrAd",
                "eUrOpE/VoLgOgRaD",
            ],
        ),
        (time_zone::europe::ZAGREB, time_zone::europe::RAW_ZAGREB, &[
            "Europe/Zagreb",
            "europe/zagreb",
            "EUROPE/ZAGREB",
            "eUROPE/zAGREB",
            "EuRoPe/zAgReB",
            "eUrOpE/ZaGrEb",
        ]),
        (time_zone::FACTORY, time_zone::RAW_FACTORY, &[
            "Factory", "factory", "FACTORY", "fACTORY", "FaCtOrY", "fAcToRy",
        ]),
        (time_zone::GB, time_zone::RAW_GB, &[
            "GB", "gb", "GB", "gb", "Gb", "gB",
        ]),
        (time_zone::GB_EIRE, time_zone::RAW_GB_EIRE, &[
            "GB-Eire", "gb-eire", "GB-EIRE", "gb-eIRE", "Gb-eIrE", "gB-EiRe",
        ]),
        (
            time_zone::europe::BELFAST,
            time_zone::europe::RAW_BELFAST,
            &[
                "Europe/Belfast",
                "europe/belfast",
                "EUROPE/BELFAST",
                "eUROPE/bELFAST",
                "EuRoPe/bElFaSt",
                "eUrOpE/BeLfAsT",
            ],
        ),
        (time_zone::europe::LONDON, time_zone::europe::RAW_LONDON, &[
            "Europe/London",
            "europe/london",
            "EUROPE/LONDON",
            "eUROPE/lONDON",
            "EuRoPe/lOnDoN",
            "eUrOpE/LoNdOn",
        ]),
        (time_zone::GMT, time_zone::RAW_GMT, &[
            "GMT", "gmt", "GMT", "gmt", "GmT", "gMt",
        ]),
        (time_zone::GMT_0, time_zone::RAW_GMT_0, &[
            "GMT0", "gmt0", "GMT0", "gmt0", "GmT0", "gMt0",
        ]),
        (time_zone::GMT_MINUS_0, time_zone::RAW_GMT_MINUS_0, &[
            "GMT-0", "gmt-0", "GMT-0", "gmt-0", "GmT-0", "gMt-0",
        ]),
        (time_zone::GMT_PLUS_0, time_zone::RAW_GMT_PLUS_0, &[
            "GMT+0", "gmt+0", "GMT+0", "gmt+0", "GmT+0", "gMt+0",
        ]),
        (time_zone::GREENWICH, time_zone::RAW_GREENWICH, &[
            "Greenwich",
            "greenwich",
            "GREENWICH",
            "gREENWICH",
            "GrEeNwIcH",
            "gReEnWiCh",
        ]),
        (time_zone::etc::GMT, time_zone::etc::RAW_GMT, &[
            "Etc/GMT", "etc/gmt", "ETC/GMT", "eTC/gmt", "EtC/GmT", "eTc/gMt",
        ]),
        (time_zone::etc::GMT_0, time_zone::etc::RAW_GMT_0, &[
            "Etc/GMT0", "etc/gmt0", "ETC/GMT0", "eTC/gmt0", "EtC/GmT0", "eTc/gMt0",
        ]),
        (
            time_zone::etc::GMT_MINUS_0,
            time_zone::etc::RAW_GMT_MINUS_0,
            &[
                "Etc/GMT-0",
                "etc/gmt-0",
                "ETC/GMT-0",
                "eTC/gmt-0",
                "EtC/GmT-0",
                "eTc/gMt-0",
            ],
        ),
        (
            time_zone::etc::GMT_PLUS_0,
            time_zone::etc::RAW_GMT_PLUS_0,
            &[
                "Etc/GMT+0",
                "etc/gmt+0",
                "ETC/GMT+0",
                "eTC/gmt+0",
                "EtC/GmT+0",
                "eTc/gMt+0",
            ],
        ),
        (time_zone::etc::GREENWICH, time_zone::etc::RAW_GREENWICH, &[
            "Etc/Greenwich",
            "etc/greenwich",
            "ETC/GREENWICH",
            "eTC/gREENWICH",
            "EtC/GrEeNwIcH",
            "eTc/gReEnWiCh",
        ]),
        (time_zone::HONGKONG, time_zone::RAW_HONGKONG, &[
            "Hongkong", "hongkong", "HONGKONG", "hONGKONG", "HoNgKoNg", "hOnGkOnG",
        ]),
        (
            time_zone::asia::HONG_KONG,
            time_zone::asia::RAW_HONG_KONG,
            &[
                "Asia/Hong_Kong",
                "asia/hong_kong",
                "ASIA/HONG_KONG",
                "aSIA/hONG_kONG",
                "AsIa/hOnG_KoNg",
                "aSiA/HoNg_kOnG",
            ],
        ),
        (time_zone::HST, time_zone::RAW_HST, &[
            "HST", "hst", "HST", "hst", "HsT", "hSt",
        ]),
        (time_zone::ICELAND, time_zone::RAW_ICELAND, &[
            "Iceland", "iceland", "ICELAND", "iCELAND", "IcElAnD", "iCeLaNd",
        ]),
        (
            time_zone::africa::ABIDJAN,
            time_zone::africa::RAW_ABIDJAN,
            &[
                "Africa/Abidjan",
                "africa/abidjan",
                "AFRICA/ABIDJAN",
                "aFRICA/aBIDJAN",
                "AfRiCa/aBiDjAn",
                "aFrIcA/AbIdJaN",
            ],
        ),
        (
            time_zone::africa::TIMBUKTU,
            time_zone::africa::RAW_TIMBUKTU,
            &[
                "Africa/Timbuktu",
                "africa/timbuktu",
                "AFRICA/TIMBUKTU",
                "aFRICA/tIMBUKTU",
                "AfRiCa/tImBuKtU",
                "aFrIcA/TiMbUkTu",
            ],
        ),
        (
            time_zone::indian::ANTANANARIVO,
            time_zone::indian::RAW_ANTANANARIVO,
            &[
                "Indian/Antananarivo",
                "indian/antananarivo",
                "INDIAN/ANTANANARIVO",
                "iNDIAN/aNTANANARIVO",
                "InDiAn/aNtAnAnArIvO",
                "iNdIaN/AnTaNaNaRiVo",
            ],
        ),
        (time_zone::indian::CHAGOS, time_zone::indian::RAW_CHAGOS, &[
            "Indian/Chagos",
            "indian/chagos",
            "INDIAN/CHAGOS",
            "iNDIAN/cHAGOS",
            "InDiAn/cHaGoS",
            "iNdIaN/ChAgOs",
        ]),
        (
            time_zone::indian::CHRISTMAS,
            time_zone::indian::RAW_CHRISTMAS,
            &[
                "Indian/Christmas",
                "indian/christmas",
                "INDIAN/CHRISTMAS",
                "iNDIAN/cHRISTMAS",
                "InDiAn/cHrIsTmAs",
                "iNdIaN/ChRiStMaS",
            ],
        ),
        (time_zone::indian::COCOS, time_zone::indian::RAW_COCOS, &[
            "Indian/Cocos",
            "indian/cocos",
            "INDIAN/COCOS",
            "iNDIAN/cOCOS",
            "InDiAn/cOcOs",
            "iNdIaN/CoCoS",
        ]),
        (time_zone::indian::COMORO, time_zone::indian::RAW_COMORO, &[
            "Indian/Comoro",
            "indian/comoro",
            "INDIAN/COMORO",
            "iNDIAN/cOMORO",
            "InDiAn/cOmOrO",
            "iNdIaN/CoMoRo",
        ]),
        (
            time_zone::indian::KERGUELEN,
            time_zone::indian::RAW_KERGUELEN,
            &[
                "Indian/Kerguelen",
                "indian/kerguelen",
                "INDIAN/KERGUELEN",
                "iNDIAN/kERGUELEN",
                "InDiAn/kErGuElEn",
                "iNdIaN/KeRgUeLeN",
            ],
        ),
        (time_zone::indian::MAHE, time_zone::indian::RAW_MAHE, &[
            "Indian/Mahe",
            "indian/mahe",
            "INDIAN/MAHE",
            "iNDIAN/mAHE",
            "InDiAn/mAhE",
            "iNdIaN/MaHe",
        ]),
        (
            time_zone::indian::MALDIVES,
            time_zone::indian::RAW_MALDIVES,
            &[
                "Indian/Maldives",
                "indian/maldives",
                "INDIAN/MALDIVES",
                "iNDIAN/mALDIVES",
                "InDiAn/mAlDiVeS",
                "iNdIaN/MaLdIvEs",
            ],
        ),
        (
            time_zone::indian::MAURITIUS,
            time_zone::indian::RAW_MAURITIUS,
            &[
                "Indian/Mauritius",
                "indian/mauritius",
                "INDIAN/MAURITIUS",
                "iNDIAN/mAURITIUS",
                "InDiAn/mAuRiTiUs",
                "iNdIaN/MaUrItIuS",
            ],
        ),
        (
            time_zone::indian::MAYOTTE,
            time_zone::indian::RAW_MAYOTTE,
            &[
                "Indian/Mayotte",
                "indian/mayotte",
                "INDIAN/MAYOTTE",
                "iNDIAN/mAYOTTE",
                "InDiAn/mAyOtTe",
                "iNdIaN/MaYoTtE",
            ],
        ),
        (
            time_zone::indian::REUNION,
            time_zone::indian::RAW_REUNION,
            &[
                "Indian/Reunion",
                "indian/reunion",
                "INDIAN/REUNION",
                "iNDIAN/rEUNION",
                "InDiAn/rEuNiOn",
                "iNdIaN/ReUnIoN",
            ],
        ),
        (time_zone::IRAN, time_zone::RAW_IRAN, &[
            "Iran", "iran", "IRAN", "iRAN", "IrAn", "iRaN",
        ]),
        (time_zone::asia::TEHRAN, time_zone::asia::RAW_TEHRAN, &[
            "Asia/Tehran",
            "asia/tehran",
            "ASIA/TEHRAN",
            "aSIA/tEHRAN",
            "AsIa/tEhRaN",
            "aSiA/TeHrAn",
        ]),
        (time_zone::ISRAEL, time_zone::RAW_ISRAEL, &[
            "Israel", "israel", "ISRAEL", "iSRAEL", "IsRaEl", "iSrAeL",
        ]),
        (
            time_zone::asia::JERUSALEM,
            time_zone::asia::RAW_JERUSALEM,
            &[
                "Asia/Jerusalem",
                "asia/jerusalem",
                "ASIA/JERUSALEM",
                "aSIA/jERUSALEM",
                "AsIa/jErUsAlEm",
                "aSiA/JeRuSaLeM",
            ],
        ),
        (time_zone::asia::TEL_AVIV, time_zone::asia::RAW_TEL_AVIV, &[
            "Asia/Tel_Aviv",
            "asia/tel_aviv",
            "ASIA/TEL_AVIV",
            "aSIA/tEL_aVIV",
            "AsIa/tEl_aViV",
            "aSiA/TeL_AvIv",
        ]),
        (time_zone::JAMAICA, time_zone::RAW_JAMAICA, &[
            "Jamaica", "jamaica", "JAMAICA", "jAMAICA", "JaMaIcA", "jAmAiCa",
        ]),
        (
            time_zone::america::JAMAICA,
            time_zone::america::RAW_JAMAICA,
            &[
                "America/Jamaica",
                "america/jamaica",
                "AMERICA/JAMAICA",
                "aMERICA/jAMAICA",
                "AmErIcA/JaMaIcA",
                "aMeRiCa/jAmAiCa",
            ],
        ),
        (time_zone::JAPAN, time_zone::RAW_JAPAN, &[
            "Japan", "japan", "JAPAN", "jAPAN", "JaPaN", "jApAn",
        ]),
        (time_zone::asia::TOKYO, time_zone::asia::RAW_TOKYO, &[
            "Asia/Tokyo",
            "asia/tokyo",
            "ASIA/TOKYO",
            "aSIA/tOKYO",
            "AsIa/tOkYo",
            "aSiA/ToKyO",
        ]),
        (time_zone::KWAJALEIN, time_zone::RAW_KWAJALEIN, &[
            "Kwajalein",
            "kwajalein",
            "KWAJALEIN",
            "kWAJALEIN",
            "KwAjAlEiN",
            "kWaJaLeIn",
        ]),
        (
            time_zone::pacific::KWAJALEIN,
            time_zone::pacific::RAW_KWAJALEIN,
            &[
                "Pacific/Kwajalein",
                "pacific/kwajalein",
                "PACIFIC/KWAJALEIN",
                "pACIFIC/kWAJALEIN",
                "PaCiFiC/KwAjAlEiN",
                "pAcIfIc/kWaJaLeIn",
            ],
        ),
        (time_zone::LIBYA, time_zone::RAW_LIBYA, &[
            "Libya", "libya", "LIBYA", "lIBYA", "LiByA", "lIbYa",
        ]),
        (
            time_zone::africa::TRIPOLI,
            time_zone::africa::RAW_TRIPOLI,
            &[
                "Africa/Tripoli",
                "africa/tripoli",
                "AFRICA/TRIPOLI",
                "aFRICA/tRIPOLI",
                "AfRiCa/tRiPoLi",
                "aFrIcA/TrIpOlI",
            ],
        ),
        (time_zone::MET, time_zone::RAW_MET, &[
            "MET", "met", "MET", "met", "MeT", "mEt",
        ]),
        (time_zone::MST, time_zone::RAW_MST, &[
            "MST", "mst", "MST", "mst", "MsT", "mSt",
        ]),
        (time_zone::MST_7_MDT, time_zone::RAW_MST_7_MDT, &[
            "MST7MDT", "mst7mdt", "MST7MDT", "mst7mdt", "MsT7MdT", "mSt7mDt",
        ]),
        (time_zone::NAVAJO, time_zone::RAW_NAVAJO, &[
            "Navajo", "navajo", "NAVAJO", "nAVAJO", "NaVaJo", "nAvAjO",
        ]),
        (
            time_zone::america::DENVER,
            time_zone::america::RAW_DENVER,
            &[
                "America/Denver",
                "america/denver",
                "AMERICA/DENVER",
                "aMERICA/dENVER",
                "AmErIcA/DeNvEr",
                "aMeRiCa/dEnVeR",
            ],
        ),
        (
            time_zone::america::SHIPROCK,
            time_zone::america::RAW_SHIPROCK,
            &[
                "America/Shiprock",
                "america/shiprock",
                "AMERICA/SHIPROCK",
                "aMERICA/sHIPROCK",
                "AmErIcA/ShIpRoCk",
                "aMeRiCa/sHiPrOcK",
            ],
        ),
        (time_zone::us::MOUNTAIN, time_zone::us::RAW_MOUNTAIN, &[
            "US/Mountain",
            "us/mountain",
            "US/MOUNTAIN",
            "us/mOUNTAIN",
            "Us/mOuNtAiN",
            "uS/MoUnTaIn",
        ]),
        (time_zone::NZ, time_zone::RAW_NZ, &[
            "NZ", "nz", "NZ", "nz", "Nz", "nZ",
        ]),
        (
            time_zone::antarctica::SOUTH_POLE,
            time_zone::antarctica::RAW_SOUTH_POLE,
            &[
                "Antarctica/South_Pole",
                "antarctica/south_pole",
                "ANTARCTICA/SOUTH_POLE",
                "aNTARCTICA/sOUTH_pOLE",
                "AnTaRcTiCa/sOuTh_pOlE",
                "aNtArCtIcA/SoUtH_PoLe",
            ],
        ),
        (
            time_zone::pacific::AUCKLAND,
            time_zone::pacific::RAW_AUCKLAND,
            &[
                "Pacific/Auckland",
                "pacific/auckland",
                "PACIFIC/AUCKLAND",
                "pACIFIC/aUCKLAND",
                "PaCiFiC/AuCkLaNd",
                "pAcIfIc/aUcKlAnD",
            ],
        ),
        (time_zone::NZ_CHAT, time_zone::RAW_NZ_CHAT, &[
            "NZ-CHAT", "nz-chat", "NZ-CHAT", "nz-chat", "Nz-cHaT", "nZ-ChAt",
        ]),
        (
            time_zone::pacific::CHATHAM,
            time_zone::pacific::RAW_CHATHAM,
            &[
                "Pacific/Chatham",
                "pacific/chatham",
                "PACIFIC/CHATHAM",
                "pACIFIC/cHATHAM",
                "PaCiFiC/ChAtHaM",
                "pAcIfIc/cHaThAm",
            ],
        ),
        (time_zone::pacific::APIA, time_zone::pacific::RAW_APIA, &[
            "Pacific/Apia",
            "pacific/apia",
            "PACIFIC/APIA",
            "pACIFIC/aPIA",
            "PaCiFiC/ApIa",
            "pAcIfIc/aPiA",
        ]),
        (
            time_zone::pacific::BOUGAINVILLE,
            time_zone::pacific::RAW_BOUGAINVILLE,
            &[
                "Pacific/Bougainville",
                "pacific/bougainville",
                "PACIFIC/BOUGAINVILLE",
                "pACIFIC/bOUGAINVILLE",
                "PaCiFiC/BoUgAiNvIlLe",
                "pAcIfIc/bOuGaInViLlE",
            ],
        ),
        (time_zone::pacific::CHUUK, time_zone::pacific::RAW_CHUUK, &[
            "Pacific/Chuuk",
            "pacific/chuuk",
            "PACIFIC/CHUUK",
            "pACIFIC/cHUUK",
            "PaCiFiC/ChUuK",
            "pAcIfIc/cHuUk",
        ]),
        (time_zone::pacific::EFATE, time_zone::pacific::RAW_EFATE, &[
            "Pacific/Efate",
            "pacific/efate",
            "PACIFIC/EFATE",
            "pACIFIC/eFATE",
            "PaCiFiC/EfAtE",
            "pAcIfIc/eFaTe",
        ]),
        (
            time_zone::pacific::ENDERBURY,
            time_zone::pacific::RAW_ENDERBURY,
            &[
                "Pacific/Enderbury",
                "pacific/enderbury",
                "PACIFIC/ENDERBURY",
                "pACIFIC/eNDERBURY",
                "PaCiFiC/EnDeRbUrY",
                "pAcIfIc/eNdErBuRy",
            ],
        ),
        (
            time_zone::pacific::KANTON,
            time_zone::pacific::RAW_KANTON,
            &[
                "Pacific/Kanton",
                "pacific/kanton",
                "PACIFIC/KANTON",
                "pACIFIC/kANTON",
                "PaCiFiC/KaNtOn",
                "pAcIfIc/kAnToN",
            ],
        ),
        (
            time_zone::pacific::FAKAOFO,
            time_zone::pacific::RAW_FAKAOFO,
            &[
                "Pacific/Fakaofo",
                "pacific/fakaofo",
                "PACIFIC/FAKAOFO",
                "pACIFIC/fAKAOFO",
                "PaCiFiC/FaKaOfO",
                "pAcIfIc/fAkAoFo",
            ],
        ),
        (time_zone::pacific::FIJI, time_zone::pacific::RAW_FIJI, &[
            "Pacific/Fiji",
            "pacific/fiji",
            "PACIFIC/FIJI",
            "pACIFIC/fIJI",
            "PaCiFiC/FiJi",
            "pAcIfIc/fIjI",
        ]),
        (
            time_zone::pacific::FUNAFUTI,
            time_zone::pacific::RAW_FUNAFUTI,
            &[
                "Pacific/Funafuti",
                "pacific/funafuti",
                "PACIFIC/FUNAFUTI",
                "pACIFIC/fUNAFUTI",
                "PaCiFiC/FuNaFuTi",
                "pAcIfIc/fUnAfUtI",
            ],
        ),
        (
            time_zone::pacific::GALAPAGOS,
            time_zone::pacific::RAW_GALAPAGOS,
            &[
                "Pacific/Galapagos",
                "pacific/galapagos",
                "PACIFIC/GALAPAGOS",
                "pACIFIC/gALAPAGOS",
                "PaCiFiC/GaLaPaGoS",
                "pAcIfIc/gAlApAgOs",
            ],
        ),
        (
            time_zone::pacific::GAMBIER,
            time_zone::pacific::RAW_GAMBIER,
            &[
                "Pacific/Gambier",
                "pacific/gambier",
                "PACIFIC/GAMBIER",
                "pACIFIC/gAMBIER",
                "PaCiFiC/GaMbIeR",
                "pAcIfIc/gAmBiEr",
            ],
        ),
        (
            time_zone::pacific::GUADALCANAL,
            time_zone::pacific::RAW_GUADALCANAL,
            &[
                "Pacific/Guadalcanal",
                "pacific/guadalcanal",
                "PACIFIC/GUADALCANAL",
                "pACIFIC/gUADALCANAL",
                "PaCiFiC/GuAdAlCaNaL",
                "pAcIfIc/gUaDaLcAnAl",
            ],
        ),
        (
            time_zone::pacific::PONAPE,
            time_zone::pacific::RAW_PONAPE,
            &[
                "Pacific/Ponape",
                "pacific/ponape",
                "PACIFIC/PONAPE",
                "pACIFIC/pONAPE",
                "PaCiFiC/PoNaPe",
                "pAcIfIc/pOnApE",
            ],
        ),
        (time_zone::pacific::GUAM, time_zone::pacific::RAW_GUAM, &[
            "Pacific/Guam",
            "pacific/guam",
            "PACIFIC/GUAM",
            "pACIFIC/gUAM",
            "PaCiFiC/GuAm",
            "pAcIfIc/gUaM",
        ]),
        (
            time_zone::pacific::HONOLULU,
            time_zone::pacific::RAW_HONOLULU,
            &[
                "Pacific/Honolulu",
                "pacific/honolulu",
                "PACIFIC/HONOLULU",
                "pACIFIC/hONOLULU",
                "PaCiFiC/HoNoLuLu",
                "pAcIfIc/hOnOlUlU",
            ],
        ),
        (
            time_zone::pacific::JOHNSTON,
            time_zone::pacific::RAW_JOHNSTON,
            &[
                "Pacific/Johnston",
                "pacific/johnston",
                "PACIFIC/JOHNSTON",
                "pACIFIC/jOHNSTON",
                "PaCiFiC/JoHnStOn",
                "pAcIfIc/jOhNsToN",
            ],
        ),
        (time_zone::us::HAWAII, time_zone::us::RAW_HAWAII, &[
            "US/Hawaii",
            "us/hawaii",
            "US/HAWAII",
            "us/hAWAII",
            "Us/hAwAiI",
            "uS/HaWaIi",
        ]),
        (
            time_zone::pacific::KIRITIMATI,
            time_zone::pacific::RAW_KIRITIMATI,
            &[
                "Pacific/Kiritimati",
                "pacific/kiritimati",
                "PACIFIC/KIRITIMATI",
                "pACIFIC/kIRITIMATI",
                "PaCiFiC/KiRiTiMaTi",
                "pAcIfIc/kIrItImAtI",
            ],
        ),
        (
            time_zone::pacific::KOSRAE,
            time_zone::pacific::RAW_KOSRAE,
            &[
                "Pacific/Kosrae",
                "pacific/kosrae",
                "PACIFIC/KOSRAE",
                "pACIFIC/kOSRAE",
                "PaCiFiC/KoSrAe",
                "pAcIfIc/kOsRaE",
            ],
        ),
        (
            time_zone::pacific::MAJURO,
            time_zone::pacific::RAW_MAJURO,
            &[
                "Pacific/Majuro",
                "pacific/majuro",
                "PACIFIC/MAJURO",
                "pACIFIC/mAJURO",
                "PaCiFiC/MaJuRo",
                "pAcIfIc/mAjUrO",
            ],
        ),
        (
            time_zone::pacific::MARQUESAS,
            time_zone::pacific::RAW_MARQUESAS,
            &[
                "Pacific/Marquesas",
                "pacific/marquesas",
                "PACIFIC/MARQUESAS",
                "pACIFIC/mARQUESAS",
                "PaCiFiC/MaRqUeSaS",
                "pAcIfIc/mArQuEsAs",
            ],
        ),
        (
            time_zone::pacific::MIDWAY,
            time_zone::pacific::RAW_MIDWAY,
            &[
                "Pacific/Midway",
                "pacific/midway",
                "PACIFIC/MIDWAY",
                "pACIFIC/mIDWAY",
                "PaCiFiC/MiDwAy",
                "pAcIfIc/mIdWaY",
            ],
        ),
        (time_zone::pacific::NAURU, time_zone::pacific::RAW_NAURU, &[
            "Pacific/Nauru",
            "pacific/nauru",
            "PACIFIC/NAURU",
            "pACIFIC/nAURU",
            "PaCiFiC/NaUrU",
            "pAcIfIc/nAuRu",
        ]),
        (time_zone::pacific::NIUE, time_zone::pacific::RAW_NIUE, &[
            "Pacific/Niue",
            "pacific/niue",
            "PACIFIC/NIUE",
            "pACIFIC/nIUE",
            "PaCiFiC/NiUe",
            "pAcIfIc/nIuE",
        ]),
        (
            time_zone::pacific::NORFOLK,
            time_zone::pacific::RAW_NORFOLK,
            &[
                "Pacific/Norfolk",
                "pacific/norfolk",
                "PACIFIC/NORFOLK",
                "pACIFIC/nORFOLK",
                "PaCiFiC/NoRfOlK",
                "pAcIfIc/nOrFoLk",
            ],
        ),
        (
            time_zone::pacific::NOUMEA,
            time_zone::pacific::RAW_NOUMEA,
            &[
                "Pacific/Noumea",
                "pacific/noumea",
                "PACIFIC/NOUMEA",
                "pACIFIC/nOUMEA",
                "PaCiFiC/NoUmEa",
                "pAcIfIc/nOuMeA",
            ],
        ),
        (
            time_zone::pacific::PAGO_PAGO,
            time_zone::pacific::RAW_PAGO_PAGO,
            &[
                "Pacific/Pago_Pago",
                "pacific/pago_pago",
                "PACIFIC/PAGO_PAGO",
                "pACIFIC/pAGO_pAGO",
                "PaCiFiC/PaGo_pAgO",
                "pAcIfIc/pAgO_PaGo",
            ],
        ),
        (time_zone::pacific::SAMOA, time_zone::pacific::RAW_SAMOA, &[
            "Pacific/Samoa",
            "pacific/samoa",
            "PACIFIC/SAMOA",
            "pACIFIC/sAMOA",
            "PaCiFiC/SaMoA",
            "pAcIfIc/sAmOa",
        ]),
        (time_zone::us::SAMOA, time_zone::us::RAW_SAMOA, &[
            "US/Samoa", "us/samoa", "US/SAMOA", "us/sAMOA", "Us/sAmOa", "uS/SaMoA",
        ]),
        (time_zone::pacific::PALAU, time_zone::pacific::RAW_PALAU, &[
            "Pacific/Palau",
            "pacific/palau",
            "PACIFIC/PALAU",
            "pACIFIC/pALAU",
            "PaCiFiC/PaLaU",
            "pAcIfIc/pAlAu",
        ]),
        (
            time_zone::pacific::PITCAIRN,
            time_zone::pacific::RAW_PITCAIRN,
            &[
                "Pacific/Pitcairn",
                "pacific/pitcairn",
                "PACIFIC/PITCAIRN",
                "pACIFIC/pITCAIRN",
                "PaCiFiC/PiTcAiRn",
                "pAcIfIc/pItCaIrN",
            ],
        ),
        (
            time_zone::pacific::POHNPEI,
            time_zone::pacific::RAW_POHNPEI,
            &[
                "Pacific/Pohnpei",
                "pacific/pohnpei",
                "PACIFIC/POHNPEI",
                "pACIFIC/pOHNPEI",
                "PaCiFiC/PoHnPeI",
                "pAcIfIc/pOhNpEi",
            ],
        ),
        (
            time_zone::pacific::PORT_MORESBY,
            time_zone::pacific::RAW_PORT_MORESBY,
            &[
                "Pacific/Port_Moresby",
                "pacific/port_moresby",
                "PACIFIC/PORT_MORESBY",
                "pACIFIC/pORT_mORESBY",
                "PaCiFiC/PoRt_mOrEsBy",
                "pAcIfIc/pOrT_MoReSbY",
            ],
        ),
        (time_zone::pacific::TRUK, time_zone::pacific::RAW_TRUK, &[
            "Pacific/Truk",
            "pacific/truk",
            "PACIFIC/TRUK",
            "pACIFIC/tRUK",
            "PaCiFiC/TrUk",
            "pAcIfIc/tRuK",
        ]),
        (time_zone::pacific::YAP, time_zone::pacific::RAW_YAP, &[
            "Pacific/Yap",
            "pacific/yap",
            "PACIFIC/YAP",
            "pACIFIC/yAP",
            "PaCiFiC/YaP",
            "pAcIfIc/yAp",
        ]),
        (
            time_zone::pacific::RAROTONGA,
            time_zone::pacific::RAW_RAROTONGA,
            &[
                "Pacific/Rarotonga",
                "pacific/rarotonga",
                "PACIFIC/RAROTONGA",
                "pACIFIC/rAROTONGA",
                "PaCiFiC/RaRoToNgA",
                "pAcIfIc/rArOtOnGa",
            ],
        ),
        (
            time_zone::pacific::SAIPAN,
            time_zone::pacific::RAW_SAIPAN,
            &[
                "Pacific/Saipan",
                "pacific/saipan",
                "PACIFIC/SAIPAN",
                "pACIFIC/sAIPAN",
                "PaCiFiC/SaIpAn",
                "pAcIfIc/sAiPaN",
            ],
        ),
        (
            time_zone::pacific::TAHITI,
            time_zone::pacific::RAW_TAHITI,
            &[
                "Pacific/Tahiti",
                "pacific/tahiti",
                "PACIFIC/TAHITI",
                "pACIFIC/tAHITI",
                "PaCiFiC/TaHiTi",
                "pAcIfIc/tAhItI",
            ],
        ),
        (
            time_zone::pacific::TARAWA,
            time_zone::pacific::RAW_TARAWA,
            &[
                "Pacific/Tarawa",
                "pacific/tarawa",
                "PACIFIC/TARAWA",
                "pACIFIC/tARAWA",
                "PaCiFiC/TaRaWa",
                "pAcIfIc/tArAwA",
            ],
        ),
        (
            time_zone::pacific::TONGATAPU,
            time_zone::pacific::RAW_TONGATAPU,
            &[
                "Pacific/Tongatapu",
                "pacific/tongatapu",
                "PACIFIC/TONGATAPU",
                "pACIFIC/tONGATAPU",
                "PaCiFiC/ToNgAtApU",
                "pAcIfIc/tOnGaTaPu",
            ],
        ),
        (time_zone::pacific::WAKE, time_zone::pacific::RAW_WAKE, &[
            "Pacific/Wake",
            "pacific/wake",
            "PACIFIC/WAKE",
            "pACIFIC/wAKE",
            "PaCiFiC/WaKe",
            "pAcIfIc/wAkE",
        ]),
        (
            time_zone::pacific::WALLIS,
            time_zone::pacific::RAW_WALLIS,
            &[
                "Pacific/Wallis",
                "pacific/wallis",
                "PACIFIC/WALLIS",
                "pACIFIC/wALLIS",
                "PaCiFiC/WaLlIs",
                "pAcIfIc/wAlLiS",
            ],
        ),
        (time_zone::POLAND, time_zone::RAW_POLAND, &[
            "Poland", "poland", "POLAND", "pOLAND", "PoLaNd", "pOlAnD",
        ]),
        (time_zone::europe::WARSAW, time_zone::europe::RAW_WARSAW, &[
            "Europe/Warsaw",
            "europe/warsaw",
            "EUROPE/WARSAW",
            "eUROPE/wARSAW",
            "EuRoPe/wArSaW",
            "eUrOpE/WaRsAw",
        ]),
        (time_zone::PORTUGAL, time_zone::RAW_PORTUGAL, &[
            "Portugal", "portugal", "PORTUGAL", "pORTUGAL", "PoRtUgAl", "pOrTuGaL",
        ]),
        (time_zone::europe::LISBON, time_zone::europe::RAW_LISBON, &[
            "Europe/Lisbon",
            "europe/lisbon",
            "EUROPE/LISBON",
            "eUROPE/lISBON",
            "EuRoPe/lIsBoN",
            "eUrOpE/LiSbOn",
        ]),
        (time_zone::PRC, time_zone::RAW_PRC, &[
            "PRC", "prc", "PRC", "prc", "PrC", "pRc",
        ]),
        (
            time_zone::asia::CHONGQING,
            time_zone::asia::RAW_CHONGQING,
            &[
                "Asia/Chongqing",
                "asia/chongqing",
                "ASIA/CHONGQING",
                "aSIA/cHONGQING",
                "AsIa/cHoNgQiNg",
                "aSiA/ChOnGqInG",
            ],
        ),
        (
            time_zone::asia::CHUNGKING,
            time_zone::asia::RAW_CHUNGKING,
            &[
                "Asia/Chungking",
                "asia/chungking",
                "ASIA/CHUNGKING",
                "aSIA/cHUNGKING",
                "AsIa/cHuNgKiNg",
                "aSiA/ChUnGkInG",
            ],
        ),
        (time_zone::asia::HARBIN, time_zone::asia::RAW_HARBIN, &[
            "Asia/Harbin",
            "asia/harbin",
            "ASIA/HARBIN",
            "aSIA/hARBIN",
            "AsIa/hArBiN",
            "aSiA/HaRbIn",
        ]),
        (time_zone::asia::SHANGHAI, time_zone::asia::RAW_SHANGHAI, &[
            "Asia/Shanghai",
            "asia/shanghai",
            "ASIA/SHANGHAI",
            "aSIA/sHANGHAI",
            "AsIa/sHaNgHaI",
            "aSiA/ShAnGhAi",
        ]),
        (time_zone::PST_8_PDT, time_zone::RAW_PST_8_PDT, &[
            "PST8PDT", "pst8pdt", "PST8PDT", "pst8pdt", "PsT8PdT", "pSt8pDt",
        ]),
        (time_zone::ROC, time_zone::RAW_ROC, &[
            "ROC", "roc", "ROC", "roc", "RoC", "rOc",
        ]),
        (time_zone::asia::TAIPEI, time_zone::asia::RAW_TAIPEI, &[
            "Asia/Taipei",
            "asia/taipei",
            "ASIA/TAIPEI",
            "aSIA/tAIPEI",
            "AsIa/tAiPeI",
            "aSiA/TaIpEi",
        ]),
        (time_zone::ROK, time_zone::RAW_ROK, &[
            "ROK", "rok", "ROK", "rok", "RoK", "rOk",
        ]),
        (time_zone::asia::SEOUL, time_zone::asia::RAW_SEOUL, &[
            "Asia/Seoul",
            "asia/seoul",
            "ASIA/SEOUL",
            "aSIA/sEOUL",
            "AsIa/sEoUl",
            "aSiA/SeOuL",
        ]),
        (time_zone::SINGAPORE, time_zone::RAW_SINGAPORE, &[
            "Singapore",
            "singapore",
            "SINGAPORE",
            "sINGAPORE",
            "SiNgApOrE",
            "sInGaPoRe",
        ]),
        (
            time_zone::asia::SINGAPORE,
            time_zone::asia::RAW_SINGAPORE,
            &[
                "Asia/Singapore",
                "asia/singapore",
                "ASIA/SINGAPORE",
                "aSIA/sINGAPORE",
                "AsIa/sInGaPoRe",
                "aSiA/SiNgApOrE",
            ],
        ),
        (time_zone::TURKEY, time_zone::RAW_TURKEY, &[
            "Turkey", "turkey", "TURKEY", "tURKEY", "TuRkEy", "tUrKeY",
        ]),
        (time_zone::asia::ISTANBUL, time_zone::asia::RAW_ISTANBUL, &[
            "Asia/Istanbul",
            "asia/istanbul",
            "ASIA/ISTANBUL",
            "aSIA/iSTANBUL",
            "AsIa/iStAnBuL",
            "aSiA/IsTaNbUl",
        ]),
        (
            time_zone::europe::ISTANBUL,
            time_zone::europe::RAW_ISTANBUL,
            &[
                "Europe/Istanbul",
                "europe/istanbul",
                "EUROPE/ISTANBUL",
                "eUROPE/iSTANBUL",
                "EuRoPe/iStAnBuL",
                "eUrOpE/IsTaNbUl",
            ],
        ),
        (time_zone::UCT, time_zone::RAW_UCT, &[
            "UCT", "uct", "UCT", "uct", "UcT", "uCt",
        ]),
        (time_zone::UNIVERSAL, time_zone::RAW_UNIVERSAL, &[
            "Universal",
            "universal",
            "UNIVERSAL",
            "uNIVERSAL",
            "UnIvErSaL",
            "uNiVeRsAl",
        ]),
        (time_zone::UTC, time_zone::RAW_UTC, &[
            "UTC", "utc", "UTC", "utc", "UtC", "uTc",
        ]),
        (time_zone::ZULU, time_zone::RAW_ZULU, &[
            "Zulu", "zulu", "ZULU", "zULU", "ZuLu", "zUlU",
        ]),
        (time_zone::etc::UCT, time_zone::etc::RAW_UCT, &[
            "Etc/UCT", "etc/uct", "ETC/UCT", "eTC/uct", "EtC/UcT", "eTc/uCt",
        ]),
        (time_zone::etc::UNIVERSAL, time_zone::etc::RAW_UNIVERSAL, &[
            "Etc/Universal",
            "etc/universal",
            "ETC/UNIVERSAL",
            "eTC/uNIVERSAL",
            "EtC/UnIvErSaL",
            "eTc/uNiVeRsAl",
        ]),
        (time_zone::etc::UTC, time_zone::etc::RAW_UTC, &[
            "Etc/UTC", "etc/utc", "ETC/UTC", "eTC/utc", "EtC/UtC", "eTc/uTc",
        ]),
        (time_zone::etc::ZULU, time_zone::etc::RAW_ZULU, &[
            "Etc/Zulu", "etc/zulu", "ETC/ZULU", "eTC/zULU", "EtC/ZuLu", "eTc/zUlU",
        ]),
        (time_zone::WET, time_zone::RAW_WET, &[
            "WET", "wet", "WET", "wet", "WeT", "wEt",
        ]),
        (time_zone::W_SU, time_zone::RAW_W_SU, &[
            "W-SU", "w-su", "W-SU", "w-su", "W-Su", "w-sU",
        ]),
        (time_zone::europe::MOSCOW, time_zone::europe::RAW_MOSCOW, &[
            "Europe/Moscow",
            "europe/moscow",
            "EUROPE/MOSCOW",
            "eUROPE/mOSCOW",
            "EuRoPe/mOsCoW",
            "eUrOpE/MoScOw",
        ]),
    ];

    for &(tz, raw, names) in TIME_ZONES {
        for name in names {
            assert_eq!(Some(tz), tz_by_name(name), "tz_by_name({:?})", name);
            assert_eq!(
                Some(raw),
                raw_tz_by_name(name),
                "raw_tz_by_name({:?})",
                name
            );
        }
    }
}
